from ....tl.mtproto_request import MTProtoRequest


class PaymentReceipt(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    payments.paymentReceipt#500911e1 flags:# date:date bot_id:int invoice:Invoice provider_id:int info:flags.0?PaymentRequestedInfo shipping:flags.1?ShippingOption currency:string total_amount:long credentials_title:string users:Vector<User> = payments.PaymentReceipt"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0x500911e1

    def __init__(self, date, bot_id, invoice, provider_id, currency, total_amount, credentials_title, users, info=None, shipping=None):
        """
        :param date: Telegram type: «date».
        :param bot_id: Telegram type: «int».
        :param invoice: Telegram type: «Invoice».
        :param provider_id: Telegram type: «int».
        :param info: Telegram type: «PaymentRequestedInfo».
        :param shipping: Telegram type: «ShippingOption».
        :param currency: Telegram type: «string».
        :param total_amount: Telegram type: «long».
        :param credentials_title: Telegram type: «string».
        :param users: Telegram type: «User». Must be a list.

        Constructor for payments.PaymentReceipt: Instance of PaymentReceipt.
        """
        super().__init__()

        self.date = date
        self.bot_id = bot_id
        self.invoice = invoice
        self.provider_id = provider_id
        self.info = info
        self.shipping = shipping
        self.currency = currency
        self.total_amount = total_amount
        self.credentials_title = credentials_title
        self.users = users

    def on_send(self, writer):
        writer.write_int(PaymentReceipt.constructor_id, signed=False)
        # Calculate the flags. This equals to those flag arguments which are NOT None
        flags = 0
        flags |= (1 << 0) if self.info else 0
        flags |= (1 << 1) if self.shipping else 0
        writer.write_int(flags)

        writer.tgwrite_date(self.date)
        writer.write_int(self.bot_id)
        self.invoice.on_send(writer)
        writer.write_int(self.provider_id)
        if self.info:
            self.info.on_send(writer)

        if self.shipping:
            self.shipping.on_send(writer)

        writer.tgwrite_string(self.currency)
        writer.write_long(self.total_amount)
        writer.tgwrite_string(self.credentials_title)
        writer.write_int(0x1cb5c415, signed=False)  # Vector's constructor ID
        writer.write_int(len(self.users))
        for users_item in self.users:
            users_item.on_send(writer)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return PaymentReceipt(None, None, None, None, None, None, None, None, None, None)

    def on_response(self, reader):
        flags = reader.read_int()

        self.date = reader.tgread_date()
        self.bot_id = reader.read_int()
        self.invoice = reader.tgread_object()
        self.provider_id = reader.read_int()
        if (flags & (1 << 0)) != 0:
            self.info = reader.tgread_object()

        if (flags & (1 << 1)) != 0:
            self.shipping = reader.tgread_object()

        self.currency = reader.tgread_string()
        self.total_amount = reader.read_long()
        self.credentials_title = reader.tgread_string()
        reader.read_int()  # Vector's constructor ID
        self.users = []  # Initialize an empty list
        users_len = reader.read_int()
        for _ in range(users_len):
            users_item = reader.tgread_object()
            self.users.append(users_item)

    def __repr__(self):
        return 'payments.paymentReceipt#500911e1 flags:# date:date bot_id:int invoice:Invoice provider_id:int info:flags.0?PaymentRequestedInfo shipping:flags.1?ShippingOption currency:string total_amount:long credentials_title:string users:Vector<User> = payments.PaymentReceipt'

    def __str__(self):
        return '(payments.paymentReceipt (ID: 0x500911e1) = (date={}, bot_id={}, invoice={}, provider_id={}, info={}, shipping={}, currency={}, total_amount={}, credentials_title={}, users={}))'.format(str(self.date), str(self.bot_id), str(self.invoice), str(self.provider_id), str(self.info), str(self.shipping), str(self.currency), str(self.total_amount), str(self.credentials_title), None if not self.users else [str(_) for _ in self.users])



from ...tl.mtproto_request import MTProtoRequest


class UserStatusOnline(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    userStatusOnline#edb93949 expires:date = UserStatus"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0xedb93949

    def __init__(self, expires):
        """
        :param expires: Telegram type: «date».

        Constructor for UserStatus: Instance of either UserStatusEmpty, UserStatusOnline, UserStatusOffline, UserStatusRecently, UserStatusLastWeek, UserStatusLastMonth.
        """
        super().__init__()

        self.expires = expires

    def on_send(self, writer):
        writer.write_int(UserStatusOnline.constructor_id, signed=False)
        writer.tgwrite_date(self.expires)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return UserStatusOnline(None)

    def on_response(self, reader):
        self.expires = reader.tgread_date()

    def __repr__(self):
        return 'userStatusOnline#edb93949 expires:date = UserStatus'

    def __str__(self):
        return '(userStatusOnline (ID: 0xedb93949) = (expires={}))'.format(str(self.expires))



from ...tl.mtproto_request import MTProtoRequest


class MsgResendReq(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    msg_resend_req#7d861a08 msg_ids:Vector<long> = MsgResendReq"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0x7d861a08

    def __init__(self, msg_ids):
        """
        :param msg_ids: Telegram type: «long». Must be a list.

        Constructor for MsgResendReq: Instance of MsgResendReq.
        """
        super().__init__()

        self.msg_ids = msg_ids

    def on_send(self, writer):
        writer.write_int(MsgResendReq.constructor_id, signed=False)
        writer.write_int(0x1cb5c415, signed=False)  # Vector's constructor ID
        writer.write_int(len(self.msg_ids))
        for msg_ids_item in self.msg_ids:
            writer.write_long(msg_ids_item)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return MsgResendReq(None)

    def on_response(self, reader):
        reader.read_int()  # Vector's constructor ID
        self.msg_ids = []  # Initialize an empty list
        msg_ids_len = reader.read_int()
        for _ in range(msg_ids_len):
            msg_ids_item = reader.read_long()
            self.msg_ids.append(msg_ids_item)

    def __repr__(self):
        return 'msg_resend_req#7d861a08 msg_ids:Vector<long> = MsgResendReq'

    def __str__(self):
        return '(msg_resend_req (ID: 0x7d861a08) = (msg_ids={}))'.format(None if not self.msg_ids else [str(_) for _ in self.msg_ids])



from ...tl.mtproto_request import MTProtoRequest


class KeyboardButtonRow(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    keyboardButtonRow#77608b83 buttons:Vector<KeyboardButton> = KeyboardButtonRow"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0x77608b83

    def __init__(self, buttons):
        """
        :param buttons: Telegram type: «KeyboardButton». Must be a list.

        Constructor for KeyboardButtonRow: Instance of KeyboardButtonRow.
        """
        super().__init__()

        self.buttons = buttons

    def on_send(self, writer):
        writer.write_int(KeyboardButtonRow.constructor_id, signed=False)
        writer.write_int(0x1cb5c415, signed=False)  # Vector's constructor ID
        writer.write_int(len(self.buttons))
        for buttons_item in self.buttons:
            buttons_item.on_send(writer)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return KeyboardButtonRow(None)

    def on_response(self, reader):
        reader.read_int()  # Vector's constructor ID
        self.buttons = []  # Initialize an empty list
        buttons_len = reader.read_int()
        for _ in range(buttons_len):
            buttons_item = reader.tgread_object()
            self.buttons.append(buttons_item)

    def __repr__(self):
        return 'keyboardButtonRow#77608b83 buttons:Vector<KeyboardButton> = KeyboardButtonRow'

    def __str__(self):
        return '(keyboardButtonRow (ID: 0x77608b83) = (buttons={}))'.format(None if not self.buttons else [str(_) for _ in self.buttons])



from ...tl.mtproto_request import MTProtoRequest


class StickerSetMultiCovered(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    stickerSetMultiCovered#3407e51b set:StickerSet covers:Vector<Document> = StickerSetCovered"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0x3407e51b

    def __init__(self, set, covers):
        """
        :param set: Telegram type: «StickerSet».
        :param covers: Telegram type: «Document». Must be a list.

        Constructor for StickerSetCovered: Instance of either StickerSetCovered, StickerSetMultiCovered.
        """
        super().__init__()

        self.set = set
        self.covers = covers

    def on_send(self, writer):
        writer.write_int(StickerSetMultiCovered.constructor_id, signed=False)
        self.set.on_send(writer)
        writer.write_int(0x1cb5c415, signed=False)  # Vector's constructor ID
        writer.write_int(len(self.covers))
        for covers_item in self.covers:
            covers_item.on_send(writer)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return StickerSetMultiCovered(None, None)

    def on_response(self, reader):
        self.set = reader.tgread_object()
        reader.read_int()  # Vector's constructor ID
        self.covers = []  # Initialize an empty list
        covers_len = reader.read_int()
        for _ in range(covers_len):
            covers_item = reader.tgread_object()
            self.covers.append(covers_item)

    def __repr__(self):
        return 'stickerSetMultiCovered#3407e51b set:StickerSet covers:Vector<Document> = StickerSetCovered'

    def __str__(self):
        return '(stickerSetMultiCovered (ID: 0x3407e51b) = (set={}, covers={}))'.format(str(self.set), None if not self.covers else [str(_) for _ in self.covers])



from ...tl.mtproto_request import MTProtoRequest


class InputPaymentCredentialsSaved(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    inputPaymentCredentialsSaved#c10eb2cf id:string tmp_password:bytes = InputPaymentCredentials"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0xc10eb2cf

    def __init__(self, id, tmp_password):
        """
        :param id: Telegram type: «string».
        :param tmp_password: Telegram type: «bytes».

        Constructor for InputPaymentCredentials: Instance of either InputPaymentCredentialsSaved, InputPaymentCredentials.
        """
        super().__init__()

        self.id = id
        self.tmp_password = tmp_password

    def on_send(self, writer):
        writer.write_int(InputPaymentCredentialsSaved.constructor_id, signed=False)
        writer.tgwrite_string(self.id)
        writer.tgwrite_bytes(self.tmp_password)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return InputPaymentCredentialsSaved(None, None)

    def on_response(self, reader):
        self.id = reader.tgread_string()
        self.tmp_password = reader.tgread_bytes()

    def __repr__(self):
        return 'inputPaymentCredentialsSaved#c10eb2cf id:string tmp_password:bytes = InputPaymentCredentials'

    def __str__(self):
        return '(inputPaymentCredentialsSaved (ID: 0xc10eb2cf) = (id={}, tmp_password={}))'.format(str(self.id), str(self.tmp_password))



from ...tl.mtproto_request import MTProtoRequest


class InputMediaUploadedDocument(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    inputMediaUploadedDocument#d070f1e9 flags:# file:InputFile mime_type:string attributes:Vector<DocumentAttribute> caption:string stickers:flags.0?Vector<InputDocument> = InputMedia"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0xd070f1e9

    def __init__(self, file, mime_type, attributes, caption, stickers=None):
        """
        :param file: Telegram type: «InputFile».
        :param mime_type: Telegram type: «string».
        :param attributes: Telegram type: «DocumentAttribute». Must be a list.
        :param caption: Telegram type: «string».
        :param stickers: Telegram type: «InputDocument». Must be a list.

        Constructor for InputMedia: Instance of either InputMediaEmpty, InputMediaUploadedPhoto, InputMediaPhoto, InputMediaGeoPoint, InputMediaContact, InputMediaUploadedDocument, InputMediaUploadedThumbDocument, InputMediaDocument, InputMediaVenue, InputMediaGifExternal, InputMediaPhotoExternal, InputMediaDocumentExternal, InputMediaGame, InputMediaInvoice.
        """
        super().__init__()

        self.file = file
        self.mime_type = mime_type
        self.attributes = attributes
        self.caption = caption
        self.stickers = stickers

    def on_send(self, writer):
        writer.write_int(InputMediaUploadedDocument.constructor_id, signed=False)
        # Calculate the flags. This equals to those flag arguments which are NOT None
        flags = 0
        flags |= (1 << 0) if self.stickers else 0
        writer.write_int(flags)

        self.file.on_send(writer)
        writer.tgwrite_string(self.mime_type)
        writer.write_int(0x1cb5c415, signed=False)  # Vector's constructor ID
        writer.write_int(len(self.attributes))
        for attributes_item in self.attributes:
            attributes_item.on_send(writer)

        writer.tgwrite_string(self.caption)
        if self.stickers:
            writer.write_int(0x1cb5c415, signed=False)  # Vector's constructor ID
            writer.write_int(len(self.stickers))
            for stickers_item in self.stickers:
                if stickers_item:
                    stickers_item.on_send(writer)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return InputMediaUploadedDocument(None, None, None, None, None)

    def on_response(self, reader):
        flags = reader.read_int()

        self.file = reader.tgread_object()
        self.mime_type = reader.tgread_string()
        reader.read_int()  # Vector's constructor ID
        self.attributes = []  # Initialize an empty list
        attributes_len = reader.read_int()
        for _ in range(attributes_len):
            attributes_item = reader.tgread_object()
            self.attributes.append(attributes_item)

        self.caption = reader.tgread_string()
        if (flags & (1 << 0)) != 0:
            reader.read_int()  # Vector's constructor ID
            self.stickers = []  # Initialize an empty list
            stickers_len = reader.read_int()
            for _ in range(stickers_len):
                stickers_item = reader.tgread_object()
                self.stickers.append(stickers_item)

    def __repr__(self):
        return 'inputMediaUploadedDocument#d070f1e9 flags:# file:InputFile mime_type:string attributes:Vector<DocumentAttribute> caption:string stickers:flags.0?Vector<InputDocument> = InputMedia'

    def __str__(self):
        return '(inputMediaUploadedDocument (ID: 0xd070f1e9) = (file={}, mime_type={}, attributes={}, caption={}, stickers={}))'.format(str(self.file), str(self.mime_type), None if not self.attributes else [str(_) for _ in self.attributes], str(self.caption), None if not self.stickers else [str(_) for _ in self.stickers])



from ...tl.mtproto_request import MTProtoRequest


class StickerPack(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    stickerPack#12b299d4 emoticon:string documents:Vector<long> = StickerPack"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0x12b299d4

    def __init__(self, emoticon, documents):
        """
        :param emoticon: Telegram type: «string».
        :param documents: Telegram type: «long». Must be a list.

        Constructor for StickerPack: Instance of StickerPack.
        """
        super().__init__()

        self.emoticon = emoticon
        self.documents = documents

    def on_send(self, writer):
        writer.write_int(StickerPack.constructor_id, signed=False)
        writer.tgwrite_string(self.emoticon)
        writer.write_int(0x1cb5c415, signed=False)  # Vector's constructor ID
        writer.write_int(len(self.documents))
        for documents_item in self.documents:
            writer.write_long(documents_item)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return StickerPack(None, None)

    def on_response(self, reader):
        self.emoticon = reader.tgread_string()
        reader.read_int()  # Vector's constructor ID
        self.documents = []  # Initialize an empty list
        documents_len = reader.read_int()
        for _ in range(documents_len):
            documents_item = reader.read_long()
            self.documents.append(documents_item)

    def __repr__(self):
        return 'stickerPack#12b299d4 emoticon:string documents:Vector<long> = StickerPack'

    def __str__(self):
        return '(stickerPack (ID: 0x12b299d4) = (emoticon={}, documents={}))'.format(str(self.emoticon), None if not self.documents else [str(_) for _ in self.documents])



from ....tl.mtproto_request import MTProtoRequest


class SentEncryptedMessage(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    messages.sentEncryptedMessage#560f8935 date:date = messages.SentEncryptedMessage"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0x560f8935

    def __init__(self, date):
        """
        :param date: Telegram type: «date».

        Constructor for messages.SentEncryptedMessage: Instance of either SentEncryptedMessage, SentEncryptedFile.
        """
        super().__init__()

        self.date = date

    def on_send(self, writer):
        writer.write_int(SentEncryptedMessage.constructor_id, signed=False)
        writer.tgwrite_date(self.date)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return SentEncryptedMessage(None)

    def on_response(self, reader):
        self.date = reader.tgread_date()

    def __repr__(self):
        return 'messages.sentEncryptedMessage#560f8935 date:date = messages.SentEncryptedMessage'

    def __str__(self):
        return '(messages.sentEncryptedMessage (ID: 0x560f8935) = (date={}))'.format(str(self.date))



from ....tl.mtproto_request import MTProtoRequest


class ReceivedQueueRequest(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    messages.receivedQueue#55a5bb66 max_qts:int = Vector<long>"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0x55a5bb66

    def __init__(self, max_qts):
        """
        :param max_qts: Telegram type: «int».

        :returns Vector<long>: This type has no constructors.
        """
        super().__init__()
        self.result = None
        self.confirmed = True  # Confirmed by default

        self.max_qts = max_qts

    def on_send(self, writer):
        writer.write_int(ReceivedQueueRequest.constructor_id, signed=False)
        writer.write_int(self.max_qts)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return ReceivedQueueRequest(None)

    def on_response(self, reader):
        reader.read_int()  # Vector id
        count = reader.read_long()
        self.result = [reader.read_long() for _ in range(count)]

    def __repr__(self):
        return 'messages.receivedQueue#55a5bb66 max_qts:int = Vector<long>'

    def __str__(self):
        return '(messages.receivedQueue (ID: 0x55a5bb66) = (max_qts={}))'.format(str(self.max_qts))



from ....tl.mtproto_request import MTProtoRequest


class HighScores(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    messages.highScores#9a3bfd99 scores:Vector<HighScore> users:Vector<User> = messages.HighScores"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0x9a3bfd99

    def __init__(self, scores, users):
        """
        :param scores: Telegram type: «HighScore». Must be a list.
        :param users: Telegram type: «User». Must be a list.

        Constructor for messages.HighScores: Instance of HighScores.
        """
        super().__init__()

        self.scores = scores
        self.users = users

    def on_send(self, writer):
        writer.write_int(HighScores.constructor_id, signed=False)
        writer.write_int(0x1cb5c415, signed=False)  # Vector's constructor ID
        writer.write_int(len(self.scores))
        for scores_item in self.scores:
            scores_item.on_send(writer)

        writer.write_int(0x1cb5c415, signed=False)  # Vector's constructor ID
        writer.write_int(len(self.users))
        for users_item in self.users:
            users_item.on_send(writer)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return HighScores(None, None)

    def on_response(self, reader):
        reader.read_int()  # Vector's constructor ID
        self.scores = []  # Initialize an empty list
        scores_len = reader.read_int()
        for _ in range(scores_len):
            scores_item = reader.tgread_object()
            self.scores.append(scores_item)

        reader.read_int()  # Vector's constructor ID
        self.users = []  # Initialize an empty list
        users_len = reader.read_int()
        for _ in range(users_len):
            users_item = reader.tgread_object()
            self.users.append(users_item)

    def __repr__(self):
        return 'messages.highScores#9a3bfd99 scores:Vector<HighScore> users:Vector<User> = messages.HighScores'

    def __str__(self):
        return '(messages.highScores (ID: 0x9a3bfd99) = (scores={}, users={}))'.format(None if not self.scores else [str(_) for _ in self.scores], None if not self.users else [str(_) for _ in self.users])



from ....tl.mtproto_request import MTProtoRequest


class DhConfigNotModified(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    messages.dhConfigNotModified#c0e24635 random:bytes = messages.DhConfig"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0xc0e24635

    def __init__(self, random):
        """
        :param random: Telegram type: «bytes».

        Constructor for messages.DhConfig: Instance of either DhConfigNotModified, DhConfig.
        """
        super().__init__()

        self.random = random

    def on_send(self, writer):
        writer.write_int(DhConfigNotModified.constructor_id, signed=False)
        writer.tgwrite_bytes(self.random)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return DhConfigNotModified(None)

    def on_response(self, reader):
        self.random = reader.tgread_bytes()

    def __repr__(self):
        return 'messages.dhConfigNotModified#c0e24635 random:bytes = messages.DhConfig'

    def __str__(self):
        return '(messages.dhConfigNotModified (ID: 0xc0e24635) = (random={}))'.format(str(self.random))



from ...tl.mtproto_request import MTProtoRequest


class UpdateUserTyping(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    updateUserTyping#5c486927 user_id:int action:SendMessageAction = Update"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0x5c486927

    def __init__(self, user_id, action):
        """
        :param user_id: Telegram type: «int».
        :param action: Telegram type: «SendMessageAction».

        Constructor for Update: Instance of either UpdateNewMessage, UpdateMessageID, UpdateDeleteMessages, UpdateUserTyping, UpdateChatUserTyping, UpdateChatParticipants, UpdateUserStatus, UpdateUserName, UpdateUserPhoto, UpdateContactRegistered, UpdateContactLink, UpdateNewEncryptedMessage, UpdateEncryptedChatTyping, UpdateEncryption, UpdateEncryptedMessagesRead, UpdateChatParticipantAdd, UpdateChatParticipantDelete, UpdateDcOptions, UpdateUserBlocked, UpdateNotifySettings, UpdateServiceNotification, UpdatePrivacy, UpdateUserPhone, UpdateReadHistoryInbox, UpdateReadHistoryOutbox, UpdateWebPage, UpdateReadMessagesContents, UpdateChannelTooLong, UpdateChannel, UpdateNewChannelMessage, UpdateReadChannelInbox, UpdateDeleteChannelMessages, UpdateChannelMessageViews, UpdateChatAdmins, UpdateChatParticipantAdmin, UpdateNewStickerSet, UpdateStickerSetsOrder, UpdateStickerSets, UpdateSavedGifs, UpdateBotInlineQuery, UpdateBotInlineSend, UpdateEditChannelMessage, UpdateChannelPinnedMessage, UpdateBotCallbackQuery, UpdateEditMessage, UpdateInlineBotCallbackQuery, UpdateReadChannelOutbox, UpdateDraftMessage, UpdateReadFeaturedStickers, UpdateRecentStickers, UpdateConfig, UpdatePtsChanged, UpdateChannelWebPage, UpdateDialogPinned, UpdatePinnedDialogs, UpdateBotWebhookJSON, UpdateBotWebhookJSONQuery, UpdateBotShippingQuery, UpdateBotPrecheckoutQuery, UpdatePhoneCall.
        """
        super().__init__()

        self.user_id = user_id
        self.action = action

    def on_send(self, writer):
        writer.write_int(UpdateUserTyping.constructor_id, signed=False)
        writer.write_int(self.user_id)
        self.action.on_send(writer)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return UpdateUserTyping(None, None)

    def on_response(self, reader):
        self.user_id = reader.read_int()
        self.action = reader.tgread_object()

    def __repr__(self):
        return 'updateUserTyping#5c486927 user_id:int action:SendMessageAction = Update'

    def __str__(self):
        return '(updateUserTyping (ID: 0x5c486927) = (user_id={}, action={}))'.format(str(self.user_id), str(self.action))



from .save_file_part import SaveFilePartRequest
from .get_file import GetFileRequest
from .save_big_file_part import SaveBigFilePartRequest
from .get_web_file import GetWebFileRequest
from .get_cdn_file import GetCdnFileRequest
from .reupload_cdn_file import ReuploadCdnFileRequest



from ....tl.mtproto_request import MTProtoRequest


class GetTmpPasswordRequest(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    account.getTmpPassword#4a82327e password_hash:bytes period:int = account.TmpPassword"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0x4a82327e

    def __init__(self, password_hash, period):
        """
        :param password_hash: Telegram type: «bytes».
        :param period: Telegram type: «int».

        :returns account.TmpPassword: Instance of TmpPassword.
        """
        super().__init__()
        self.result = None
        self.confirmed = True  # Confirmed by default

        self.password_hash = password_hash
        self.period = period

    def on_send(self, writer):
        writer.write_int(GetTmpPasswordRequest.constructor_id, signed=False)
        writer.tgwrite_bytes(self.password_hash)
        writer.write_int(self.period)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return GetTmpPasswordRequest(None, None)

    def on_response(self, reader):
        self.result = reader.tgread_object()

    def __repr__(self):
        return 'account.getTmpPassword#4a82327e password_hash:bytes period:int = account.TmpPassword'

    def __str__(self):
        return '(account.getTmpPassword (ID: 0x4a82327e) = (password_hash={}, period={}))'.format(str(self.password_hash), str(self.period))



from ...tl.mtproto_request import MTProtoRequest


class MessageActionPaymentSent(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    messageActionPaymentSent#40699cd0 currency:string total_amount:long = MessageAction"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0x40699cd0

    def __init__(self, currency, total_amount):
        """
        :param currency: Telegram type: «string».
        :param total_amount: Telegram type: «long».

        Constructor for MessageAction: Instance of either MessageActionEmpty, MessageActionChatCreate, MessageActionChatEditTitle, MessageActionChatEditPhoto, MessageActionChatDeletePhoto, MessageActionChatAddUser, MessageActionChatDeleteUser, MessageActionChatJoinedByLink, MessageActionChannelCreate, MessageActionChatMigrateTo, MessageActionChannelMigrateFrom, MessageActionPinMessage, MessageActionHistoryClear, MessageActionGameScore, MessageActionPaymentSentMe, MessageActionPaymentSent, MessageActionPhoneCall.
        """
        super().__init__()

        self.currency = currency
        self.total_amount = total_amount

    def on_send(self, writer):
        writer.write_int(MessageActionPaymentSent.constructor_id, signed=False)
        writer.tgwrite_string(self.currency)
        writer.write_long(self.total_amount)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return MessageActionPaymentSent(None, None)

    def on_response(self, reader):
        self.currency = reader.tgread_string()
        self.total_amount = reader.read_long()

    def __repr__(self):
        return 'messageActionPaymentSent#40699cd0 currency:string total_amount:long = MessageAction'

    def __str__(self):
        return '(messageActionPaymentSent (ID: 0x40699cd0) = (currency={}, total_amount={}))'.format(str(self.currency), str(self.total_amount))



from ...tl.mtproto_request import MTProtoRequest


class InputEncryptedFileBigUploaded(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    inputEncryptedFileBigUploaded#2dc173c8 id:long parts:int key_fingerprint:int = InputEncryptedFile"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0x2dc173c8

    def __init__(self, id, parts, key_fingerprint):
        """
        :param id: Telegram type: «long».
        :param parts: Telegram type: «int».
        :param key_fingerprint: Telegram type: «int».

        Constructor for InputEncryptedFile: Instance of either InputEncryptedFileEmpty, InputEncryptedFileUploaded, InputEncryptedFile, InputEncryptedFileBigUploaded.
        """
        super().__init__()

        self.id = id
        self.parts = parts
        self.key_fingerprint = key_fingerprint

    def on_send(self, writer):
        writer.write_int(InputEncryptedFileBigUploaded.constructor_id, signed=False)
        writer.write_long(self.id)
        writer.write_int(self.parts)
        writer.write_int(self.key_fingerprint)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return InputEncryptedFileBigUploaded(None, None, None)

    def on_response(self, reader):
        self.id = reader.read_long()
        self.parts = reader.read_int()
        self.key_fingerprint = reader.read_int()

    def __repr__(self):
        return 'inputEncryptedFileBigUploaded#2dc173c8 id:long parts:int key_fingerprint:int = InputEncryptedFile'

    def __str__(self):
        return '(inputEncryptedFileBigUploaded (ID: 0x2dc173c8) = (id={}, parts={}, key_fingerprint={}))'.format(str(self.id), str(self.parts), str(self.key_fingerprint))



from ....tl.mtproto_request import MTProtoRequest


class ClearSavedInfoRequest(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    payments.clearSavedInfo#d83d70c1 flags:# credentials:flags.0?true info:flags.1?true = Bool"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0xd83d70c1

    def __init__(self, credentials=None, info=None):
        """
        :param credentials: Telegram type: «true».
        :param info: Telegram type: «true».

        :returns Bool: This type has no constructors.
        """
        super().__init__()
        self.result = None
        self.confirmed = True  # Confirmed by default

        self.credentials = credentials
        self.info = info

    def on_send(self, writer):
        writer.write_int(ClearSavedInfoRequest.constructor_id, signed=False)
        # Calculate the flags. This equals to those flag arguments which are NOT None
        flags = 0
        flags |= (1 << 0) if self.credentials else 0
        flags |= (1 << 1) if self.info else 0
        writer.write_int(flags)


    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return ClearSavedInfoRequest(None, None)

    def on_response(self, reader):
        self.result = reader.tgread_object()

    def __repr__(self):
        return 'payments.clearSavedInfo#d83d70c1 flags:# credentials:flags.0?true info:flags.1?true = Bool'

    def __str__(self):
        return '(payments.clearSavedInfo (ID: 0xd83d70c1) = (credentials={}, info={}))'.format(str(self.credentials), str(self.info))



from ...tl.mtproto_request import MTProtoRequest


class DocumentAttributeImageSize(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    documentAttributeImageSize#6c37c15c w:int h:int = DocumentAttribute"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0x6c37c15c

    def __init__(self, w, h):
        """
        :param w: Telegram type: «int».
        :param h: Telegram type: «int».

        Constructor for DocumentAttribute: Instance of either DocumentAttributeImageSize, DocumentAttributeAnimated, DocumentAttributeSticker, DocumentAttributeVideo, DocumentAttributeAudio, DocumentAttributeFilename, DocumentAttributeHasStickers.
        """
        super().__init__()

        self.w = w
        self.h = h

    def on_send(self, writer):
        writer.write_int(DocumentAttributeImageSize.constructor_id, signed=False)
        writer.write_int(self.w)
        writer.write_int(self.h)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return DocumentAttributeImageSize(None, None)

    def on_response(self, reader):
        self.w = reader.read_int()
        self.h = reader.read_int()

    def __repr__(self):
        return 'documentAttributeImageSize#6c37c15c w:int h:int = DocumentAttribute'

    def __str__(self):
        return '(documentAttributeImageSize (ID: 0x6c37c15c) = (w={}, h={}))'.format(str(self.w), str(self.h))



from ....tl.mtproto_request import MTProtoRequest


class GetCdnFileRequest(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    upload.getCdnFile#2000bcc3 file_token:bytes offset:int limit:int = upload.CdnFile"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0x2000bcc3

    def __init__(self, file_token, offset, limit):
        """
        :param file_token: Telegram type: «bytes».
        :param offset: Telegram type: «int».
        :param limit: Telegram type: «int».

        :returns upload.CdnFile: Instance of either CdnFileReuploadNeeded, CdnFile.
        """
        super().__init__()
        self.result = None
        self.confirmed = True  # Confirmed by default

        self.file_token = file_token
        self.offset = offset
        self.limit = limit

    def on_send(self, writer):
        writer.write_int(GetCdnFileRequest.constructor_id, signed=False)
        writer.tgwrite_bytes(self.file_token)
        writer.write_int(self.offset)
        writer.write_int(self.limit)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return GetCdnFileRequest(None, None, None)

    def on_response(self, reader):
        self.result = reader.tgread_object()

    def __repr__(self):
        return 'upload.getCdnFile#2000bcc3 file_token:bytes offset:int limit:int = upload.CdnFile'

    def __str__(self):
        return '(upload.getCdnFile (ID: 0x2000bcc3) = (file_token={}, offset={}, limit={}))'.format(str(self.file_token), str(self.offset), str(self.limit))



from ...tl.mtproto_request import MTProtoRequest


class MessageMediaInvoice(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    messageMediaInvoice#84551347 flags:# shipping_address_requested:flags.1?true test:flags.3?true title:string description:string photo:flags.0?WebDocument receipt_msg_id:flags.2?int currency:string total_amount:long start_param:string = MessageMedia"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0x84551347

    def __init__(self, title, description, currency, total_amount, start_param, shipping_address_requested=None, test=None, photo=None, receipt_msg_id=None):
        """
        :param shipping_address_requested: Telegram type: «true».
        :param test: Telegram type: «true».
        :param title: Telegram type: «string».
        :param description: Telegram type: «string».
        :param photo: Telegram type: «WebDocument».
        :param receipt_msg_id: Telegram type: «int».
        :param currency: Telegram type: «string».
        :param total_amount: Telegram type: «long».
        :param start_param: Telegram type: «string».

        Constructor for MessageMedia: Instance of either MessageMediaEmpty, MessageMediaPhoto, MessageMediaGeo, MessageMediaContact, MessageMediaUnsupported, MessageMediaDocument, MessageMediaWebPage, MessageMediaVenue, MessageMediaGame, MessageMediaInvoice.
        """
        super().__init__()

        self.shipping_address_requested = shipping_address_requested
        self.test = test
        self.title = title
        self.description = description
        self.photo = photo
        self.receipt_msg_id = receipt_msg_id
        self.currency = currency
        self.total_amount = total_amount
        self.start_param = start_param

    def on_send(self, writer):
        writer.write_int(MessageMediaInvoice.constructor_id, signed=False)
        # Calculate the flags. This equals to those flag arguments which are NOT None
        flags = 0
        flags |= (1 << 1) if self.shipping_address_requested else 0
        flags |= (1 << 3) if self.test else 0
        flags |= (1 << 0) if self.photo else 0
        flags |= (1 << 2) if self.receipt_msg_id else 0
        writer.write_int(flags)

        writer.tgwrite_string(self.title)
        writer.tgwrite_string(self.description)
        if self.photo:
            self.photo.on_send(writer)

        if self.receipt_msg_id:
            writer.write_int(self.receipt_msg_id)

        writer.tgwrite_string(self.currency)
        writer.write_long(self.total_amount)
        writer.tgwrite_string(self.start_param)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return MessageMediaInvoice(None, None, None, None, None, None, None, None, None)

    def on_response(self, reader):
        flags = reader.read_int()

        if (flags & (1 << 1)) != 0:
            self.shipping_address_requested = True  # Arbitrary not-None value, no need to read since it is a flag

        if (flags & (1 << 3)) != 0:
            self.test = True  # Arbitrary not-None value, no need to read since it is a flag

        self.title = reader.tgread_string()
        self.description = reader.tgread_string()
        if (flags & (1 << 0)) != 0:
            self.photo = reader.tgread_object()

        if (flags & (1 << 2)) != 0:
            self.receipt_msg_id = reader.read_int()

        self.currency = reader.tgread_string()
        self.total_amount = reader.read_long()
        self.start_param = reader.tgread_string()

    def __repr__(self):
        return 'messageMediaInvoice#84551347 flags:# shipping_address_requested:flags.1?true test:flags.3?true title:string description:string photo:flags.0?WebDocument receipt_msg_id:flags.2?int currency:string total_amount:long start_param:string = MessageMedia'

    def __str__(self):
        return '(messageMediaInvoice (ID: 0x84551347) = (shipping_address_requested={}, test={}, title={}, description={}, photo={}, receipt_msg_id={}, currency={}, total_amount={}, start_param={}))'.format(str(self.shipping_address_requested), str(self.test), str(self.title), str(self.description), str(self.photo), str(self.receipt_msg_id), str(self.currency), str(self.total_amount), str(self.start_param))



from .read_history import ReadHistoryRequest
from .delete_messages import DeleteMessagesRequest
from .delete_user_history import DeleteUserHistoryRequest
from .report_spam import ReportSpamRequest
from .get_messages import GetMessagesRequest
from .get_participants import GetParticipantsRequest
from .get_participant import GetParticipantRequest
from .get_channels import GetChannelsRequest
from .get_full_channel import GetFullChannelRequest
from .create_channel import CreateChannelRequest
from .edit_about import EditAboutRequest
from .edit_admin import EditAdminRequest
from .edit_title import EditTitleRequest
from .edit_photo import EditPhotoRequest
from .check_username import CheckUsernameRequest
from .update_username import UpdateUsernameRequest
from .join_channel import JoinChannelRequest
from .leave_channel import LeaveChannelRequest
from .invite_to_channel import InviteToChannelRequest
from .kick_from_channel import KickFromChannelRequest
from .export_invite import ExportInviteRequest
from .delete_channel import DeleteChannelRequest
from .toggle_invites import ToggleInvitesRequest
from .export_message_link import ExportMessageLinkRequest
from .toggle_signatures import ToggleSignaturesRequest
from .update_pinned_message import UpdatePinnedMessageRequest
from .get_admined_public_channels import GetAdminedPublicChannelsRequest



from ....tl.mtproto_request import MTProtoRequest


class SetInlineBotResultsRequest(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    messages.setInlineBotResults#eb5ea206 flags:# gallery:flags.0?true private:flags.1?true query_id:long results:Vector<InputBotInlineResult> cache_time:int next_offset:flags.2?string switch_pm:flags.3?InlineBotSwitchPM = Bool"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0xeb5ea206

    def __init__(self, query_id, results, cache_time, gallery=None, private=None, next_offset=None, switch_pm=None):
        """
        :param gallery: Telegram type: «true».
        :param private: Telegram type: «true».
        :param query_id: Telegram type: «long».
        :param results: Telegram type: «InputBotInlineResult». Must be a list.
        :param cache_time: Telegram type: «int».
        :param next_offset: Telegram type: «string».
        :param switch_pm: Telegram type: «InlineBotSwitchPM».

        :returns Bool: This type has no constructors.
        """
        super().__init__()
        self.result = None
        self.confirmed = True  # Confirmed by default

        self.gallery = gallery
        self.private = private
        self.query_id = query_id
        self.results = results
        self.cache_time = cache_time
        self.next_offset = next_offset
        self.switch_pm = switch_pm

    def on_send(self, writer):
        writer.write_int(SetInlineBotResultsRequest.constructor_id, signed=False)
        # Calculate the flags. This equals to those flag arguments which are NOT None
        flags = 0
        flags |= (1 << 0) if self.gallery else 0
        flags |= (1 << 1) if self.private else 0
        flags |= (1 << 2) if self.next_offset else 0
        flags |= (1 << 3) if self.switch_pm else 0
        writer.write_int(flags)

        writer.write_long(self.query_id)
        writer.write_int(0x1cb5c415, signed=False)  # Vector's constructor ID
        writer.write_int(len(self.results))
        for results_item in self.results:
            results_item.on_send(writer)

        writer.write_int(self.cache_time)
        if self.next_offset:
            writer.tgwrite_string(self.next_offset)

        if self.switch_pm:
            self.switch_pm.on_send(writer)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return SetInlineBotResultsRequest(None, None, None, None, None, None, None)

    def on_response(self, reader):
        self.result = reader.tgread_object()

    def __repr__(self):
        return 'messages.setInlineBotResults#eb5ea206 flags:# gallery:flags.0?true private:flags.1?true query_id:long results:Vector<InputBotInlineResult> cache_time:int next_offset:flags.2?string switch_pm:flags.3?InlineBotSwitchPM = Bool'

    def __str__(self):
        return '(messages.setInlineBotResults (ID: 0xeb5ea206) = (gallery={}, private={}, query_id={}, results={}, cache_time={}, next_offset={}, switch_pm={}))'.format(str(self.gallery), str(self.private), str(self.query_id), None if not self.results else [str(_) for _ in self.results], str(self.cache_time), str(self.next_offset), str(self.switch_pm))



from ....tl.mtproto_request import MTProtoRequest


class Photos(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    photos.photos#8dca6aa5 photos:Vector<Photo> users:Vector<User> = photos.Photos"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0x8dca6aa5

    def __init__(self, photos, users):
        """
        :param photos: Telegram type: «Photo». Must be a list.
        :param users: Telegram type: «User». Must be a list.

        Constructor for photos.Photos: Instance of either Photos, PhotosSlice.
        """
        super().__init__()

        self.photos = photos
        self.users = users

    def on_send(self, writer):
        writer.write_int(Photos.constructor_id, signed=False)
        writer.write_int(0x1cb5c415, signed=False)  # Vector's constructor ID
        writer.write_int(len(self.photos))
        for photos_item in self.photos:
            photos_item.on_send(writer)

        writer.write_int(0x1cb5c415, signed=False)  # Vector's constructor ID
        writer.write_int(len(self.users))
        for users_item in self.users:
            users_item.on_send(writer)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return Photos(None, None)

    def on_response(self, reader):
        reader.read_int()  # Vector's constructor ID
        self.photos = []  # Initialize an empty list
        photos_len = reader.read_int()
        for _ in range(photos_len):
            photos_item = reader.tgread_object()
            self.photos.append(photos_item)

        reader.read_int()  # Vector's constructor ID
        self.users = []  # Initialize an empty list
        users_len = reader.read_int()
        for _ in range(users_len):
            users_item = reader.tgread_object()
            self.users.append(users_item)

    def __repr__(self):
        return 'photos.photos#8dca6aa5 photos:Vector<Photo> users:Vector<User> = photos.Photos'

    def __str__(self):
        return '(photos.photos (ID: 0x8dca6aa5) = (photos={}, users={}))'.format(None if not self.photos else [str(_) for _ in self.photos], None if not self.users else [str(_) for _ in self.users])



from ....tl.mtproto_request import MTProtoRequest


class CdnFileReuploadNeeded(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    upload.cdnFileReuploadNeeded#eea8e46e request_token:bytes = upload.CdnFile"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0xeea8e46e

    def __init__(self, request_token):
        """
        :param request_token: Telegram type: «bytes».

        Constructor for upload.CdnFile: Instance of either CdnFileReuploadNeeded, CdnFile.
        """
        super().__init__()

        self.request_token = request_token

    def on_send(self, writer):
        writer.write_int(CdnFileReuploadNeeded.constructor_id, signed=False)
        writer.tgwrite_bytes(self.request_token)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return CdnFileReuploadNeeded(None)

    def on_response(self, reader):
        self.request_token = reader.tgread_bytes()

    def __repr__(self):
        return 'upload.cdnFileReuploadNeeded#eea8e46e request_token:bytes = upload.CdnFile'

    def __str__(self):
        return '(upload.cdnFileReuploadNeeded (ID: 0xeea8e46e) = (request_token={}))'.format(str(self.request_token))



from ....tl.mtproto_request import MTProtoRequest


class GetHistoryRequest(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    messages.getHistory#afa92846 peer:InputPeer offset_id:int offset_date:date add_offset:int limit:int max_id:int min_id:int = messages.Messages"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0xafa92846

    def __init__(self, peer, offset_id, offset_date, add_offset, limit, max_id, min_id):
        """
        :param peer: Telegram type: «InputPeer».
        :param offset_id: Telegram type: «int».
        :param offset_date: Telegram type: «date».
        :param add_offset: Telegram type: «int».
        :param limit: Telegram type: «int».
        :param max_id: Telegram type: «int».
        :param min_id: Telegram type: «int».

        :returns messages.Messages: Instance of either Messages, MessagesSlice, ChannelMessages.
        """
        super().__init__()
        self.result = None
        self.confirmed = True  # Confirmed by default

        self.peer = peer
        self.offset_id = offset_id
        self.offset_date = offset_date
        self.add_offset = add_offset
        self.limit = limit
        self.max_id = max_id
        self.min_id = min_id

    def on_send(self, writer):
        writer.write_int(GetHistoryRequest.constructor_id, signed=False)
        self.peer.on_send(writer)
        writer.write_int(self.offset_id)
        writer.tgwrite_date(self.offset_date)
        writer.write_int(self.add_offset)
        writer.write_int(self.limit)
        writer.write_int(self.max_id)
        writer.write_int(self.min_id)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return GetHistoryRequest(None, None, None, None, None, None, None)

    def on_response(self, reader):
        self.result = reader.tgread_object()

    def __repr__(self):
        return 'messages.getHistory#afa92846 peer:InputPeer offset_id:int offset_date:date add_offset:int limit:int max_id:int min_id:int = messages.Messages'

    def __str__(self):
        return '(messages.getHistory (ID: 0xafa92846) = (peer={}, offset_id={}, offset_date={}, add_offset={}, limit={}, max_id={}, min_id={}))'.format(str(self.peer), str(self.offset_id), str(self.offset_date), str(self.add_offset), str(self.limit), str(self.max_id), str(self.min_id))



from ...tl.mtproto_request import MTProtoRequest


class UpdateStickerSetsOrder(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    updateStickerSetsOrder#0bb2d201 flags:# masks:flags.0?true order:Vector<long> = Update"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0xbb2d201

    def __init__(self, order, masks=None):
        """
        :param masks: Telegram type: «true».
        :param order: Telegram type: «long». Must be a list.

        Constructor for Update: Instance of either UpdateNewMessage, UpdateMessageID, UpdateDeleteMessages, UpdateUserTyping, UpdateChatUserTyping, UpdateChatParticipants, UpdateUserStatus, UpdateUserName, UpdateUserPhoto, UpdateContactRegistered, UpdateContactLink, UpdateNewEncryptedMessage, UpdateEncryptedChatTyping, UpdateEncryption, UpdateEncryptedMessagesRead, UpdateChatParticipantAdd, UpdateChatParticipantDelete, UpdateDcOptions, UpdateUserBlocked, UpdateNotifySettings, UpdateServiceNotification, UpdatePrivacy, UpdateUserPhone, UpdateReadHistoryInbox, UpdateReadHistoryOutbox, UpdateWebPage, UpdateReadMessagesContents, UpdateChannelTooLong, UpdateChannel, UpdateNewChannelMessage, UpdateReadChannelInbox, UpdateDeleteChannelMessages, UpdateChannelMessageViews, UpdateChatAdmins, UpdateChatParticipantAdmin, UpdateNewStickerSet, UpdateStickerSetsOrder, UpdateStickerSets, UpdateSavedGifs, UpdateBotInlineQuery, UpdateBotInlineSend, UpdateEditChannelMessage, UpdateChannelPinnedMessage, UpdateBotCallbackQuery, UpdateEditMessage, UpdateInlineBotCallbackQuery, UpdateReadChannelOutbox, UpdateDraftMessage, UpdateReadFeaturedStickers, UpdateRecentStickers, UpdateConfig, UpdatePtsChanged, UpdateChannelWebPage, UpdateDialogPinned, UpdatePinnedDialogs, UpdateBotWebhookJSON, UpdateBotWebhookJSONQuery, UpdateBotShippingQuery, UpdateBotPrecheckoutQuery, UpdatePhoneCall.
        """
        super().__init__()

        self.masks = masks
        self.order = order

    def on_send(self, writer):
        writer.write_int(UpdateStickerSetsOrder.constructor_id, signed=False)
        # Calculate the flags. This equals to those flag arguments which are NOT None
        flags = 0
        flags |= (1 << 0) if self.masks else 0
        writer.write_int(flags)

        writer.write_int(0x1cb5c415, signed=False)  # Vector's constructor ID
        writer.write_int(len(self.order))
        for order_item in self.order:
            writer.write_long(order_item)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return UpdateStickerSetsOrder(None, None)

    def on_response(self, reader):
        flags = reader.read_int()

        if (flags & (1 << 0)) != 0:
            self.masks = True  # Arbitrary not-None value, no need to read since it is a flag

        reader.read_int()  # Vector's constructor ID
        self.order = []  # Initialize an empty list
        order_len = reader.read_int()
        for _ in range(order_len):
            order_item = reader.read_long()
            self.order.append(order_item)

    def __repr__(self):
        return 'updateStickerSetsOrder#0bb2d201 flags:# masks:flags.0?true order:Vector<long> = Update'

    def __str__(self):
        return '(updateStickerSetsOrder (ID: 0xbb2d201) = (masks={}, order={}))'.format(str(self.masks), None if not self.order else [str(_) for _ in self.order])



from ....tl.mtproto_request import MTProtoRequest


class GetRecentStickersRequest(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    messages.getRecentStickers#5ea192c9 flags:# attached:flags.0?true hash:int = messages.RecentStickers"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0x5ea192c9

    def __init__(self, hash, attached=None):
        """
        :param attached: Telegram type: «true».
        :param hash: Telegram type: «int».

        :returns messages.RecentStickers: Instance of either RecentStickersNotModified, RecentStickers.
        """
        super().__init__()
        self.result = None
        self.confirmed = True  # Confirmed by default

        self.attached = attached
        self.hash = hash

    def on_send(self, writer):
        writer.write_int(GetRecentStickersRequest.constructor_id, signed=False)
        # Calculate the flags. This equals to those flag arguments which are NOT None
        flags = 0
        flags |= (1 << 0) if self.attached else 0
        writer.write_int(flags)

        writer.write_int(self.hash)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return GetRecentStickersRequest(None, None)

    def on_response(self, reader):
        self.result = reader.tgread_object()

    def __repr__(self):
        return 'messages.getRecentStickers#5ea192c9 flags:# attached:flags.0?true hash:int = messages.RecentStickers'

    def __str__(self):
        return '(messages.getRecentStickers (ID: 0x5ea192c9) = (attached={}, hash={}))'.format(str(self.attached), str(self.hash))



from ...tl.mtproto_request import MTProtoRequest


class UpdateMessageID(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    updateMessageID#4e90bfd6 id:int random_id:long = Update"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0x4e90bfd6

    def __init__(self, id, random_id):
        """
        :param id: Telegram type: «int».
        :param random_id: Telegram type: «long».

        Constructor for Update: Instance of either UpdateNewMessage, UpdateMessageID, UpdateDeleteMessages, UpdateUserTyping, UpdateChatUserTyping, UpdateChatParticipants, UpdateUserStatus, UpdateUserName, UpdateUserPhoto, UpdateContactRegistered, UpdateContactLink, UpdateNewEncryptedMessage, UpdateEncryptedChatTyping, UpdateEncryption, UpdateEncryptedMessagesRead, UpdateChatParticipantAdd, UpdateChatParticipantDelete, UpdateDcOptions, UpdateUserBlocked, UpdateNotifySettings, UpdateServiceNotification, UpdatePrivacy, UpdateUserPhone, UpdateReadHistoryInbox, UpdateReadHistoryOutbox, UpdateWebPage, UpdateReadMessagesContents, UpdateChannelTooLong, UpdateChannel, UpdateNewChannelMessage, UpdateReadChannelInbox, UpdateDeleteChannelMessages, UpdateChannelMessageViews, UpdateChatAdmins, UpdateChatParticipantAdmin, UpdateNewStickerSet, UpdateStickerSetsOrder, UpdateStickerSets, UpdateSavedGifs, UpdateBotInlineQuery, UpdateBotInlineSend, UpdateEditChannelMessage, UpdateChannelPinnedMessage, UpdateBotCallbackQuery, UpdateEditMessage, UpdateInlineBotCallbackQuery, UpdateReadChannelOutbox, UpdateDraftMessage, UpdateReadFeaturedStickers, UpdateRecentStickers, UpdateConfig, UpdatePtsChanged, UpdateChannelWebPage, UpdateDialogPinned, UpdatePinnedDialogs, UpdateBotWebhookJSON, UpdateBotWebhookJSONQuery, UpdateBotShippingQuery, UpdateBotPrecheckoutQuery, UpdatePhoneCall.
        """
        super().__init__()

        self.id = id
        self.random_id = random_id

    def on_send(self, writer):
        writer.write_int(UpdateMessageID.constructor_id, signed=False)
        writer.write_int(self.id)
        writer.write_long(self.random_id)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return UpdateMessageID(None, None)

    def on_response(self, reader):
        self.id = reader.read_int()
        self.random_id = reader.read_long()

    def __repr__(self):
        return 'updateMessageID#4e90bfd6 id:int random_id:long = Update'

    def __str__(self):
        return '(updateMessageID (ID: 0x4e90bfd6) = (id={}, random_id={}))'.format(str(self.id), str(self.random_id))



from ....tl.mtproto_request import MTProtoRequest


class UnregisterDeviceRequest(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    account.unregisterDevice#65c55b40 token_type:int token:string = Bool"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0x65c55b40

    def __init__(self, token_type, token):
        """
        :param token_type: Telegram type: «int».
        :param token: Telegram type: «string».

        :returns Bool: This type has no constructors.
        """
        super().__init__()
        self.result = None
        self.confirmed = True  # Confirmed by default

        self.token_type = token_type
        self.token = token

    def on_send(self, writer):
        writer.write_int(UnregisterDeviceRequest.constructor_id, signed=False)
        writer.write_int(self.token_type)
        writer.tgwrite_string(self.token)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return UnregisterDeviceRequest(None, None)

    def on_response(self, reader):
        self.result = reader.tgread_object()

    def __repr__(self):
        return 'account.unregisterDevice#65c55b40 token_type:int token:string = Bool'

    def __str__(self):
        return '(account.unregisterDevice (ID: 0x65c55b40) = (token_type={}, token={}))'.format(str(self.token_type), str(self.token))



from ...tl.mtproto_request import MTProtoRequest


class BotInlineMessageText(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    botInlineMessageText#8c7f65e2 flags:# no_webpage:flags.0?true message:string entities:flags.1?Vector<MessageEntity> reply_markup:flags.2?ReplyMarkup = BotInlineMessage"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0x8c7f65e2

    def __init__(self, message, no_webpage=None, entities=None, reply_markup=None):
        """
        :param no_webpage: Telegram type: «true».
        :param message: Telegram type: «string».
        :param entities: Telegram type: «MessageEntity». Must be a list.
        :param reply_markup: Telegram type: «ReplyMarkup».

        Constructor for BotInlineMessage: Instance of either BotInlineMessageMediaAuto, BotInlineMessageText, BotInlineMessageMediaGeo, BotInlineMessageMediaVenue, BotInlineMessageMediaContact.
        """
        super().__init__()

        self.no_webpage = no_webpage
        self.message = message
        self.entities = entities
        self.reply_markup = reply_markup

    def on_send(self, writer):
        writer.write_int(BotInlineMessageText.constructor_id, signed=False)
        # Calculate the flags. This equals to those flag arguments which are NOT None
        flags = 0
        flags |= (1 << 0) if self.no_webpage else 0
        flags |= (1 << 1) if self.entities else 0
        flags |= (1 << 2) if self.reply_markup else 0
        writer.write_int(flags)

        writer.tgwrite_string(self.message)
        if self.entities:
            writer.write_int(0x1cb5c415, signed=False)  # Vector's constructor ID
            writer.write_int(len(self.entities))
            for entities_item in self.entities:
                if entities_item:
                    entities_item.on_send(writer)

        if self.reply_markup:
            self.reply_markup.on_send(writer)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return BotInlineMessageText(None, None, None, None)

    def on_response(self, reader):
        flags = reader.read_int()

        if (flags & (1 << 0)) != 0:
            self.no_webpage = True  # Arbitrary not-None value, no need to read since it is a flag

        self.message = reader.tgread_string()
        if (flags & (1 << 1)) != 0:
            reader.read_int()  # Vector's constructor ID
            self.entities = []  # Initialize an empty list
            entities_len = reader.read_int()
            for _ in range(entities_len):
                entities_item = reader.tgread_object()
                self.entities.append(entities_item)

        if (flags & (1 << 2)) != 0:
            self.reply_markup = reader.tgread_object()

    def __repr__(self):
        return 'botInlineMessageText#8c7f65e2 flags:# no_webpage:flags.0?true message:string entities:flags.1?Vector<MessageEntity> reply_markup:flags.2?ReplyMarkup = BotInlineMessage'

    def __str__(self):
        return '(botInlineMessageText (ID: 0x8c7f65e2) = (no_webpage={}, message={}, entities={}, reply_markup={}))'.format(str(self.no_webpage), str(self.message), None if not self.entities else [str(_) for _ in self.entities], str(self.reply_markup))



from ...tl.mtproto_request import MTProtoRequest


class UpdateDcOptions(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    updateDcOptions#8e5e9873 dc_options:Vector<DcOption> = Update"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0x8e5e9873

    def __init__(self, dc_options):
        """
        :param dc_options: Telegram type: «DcOption». Must be a list.

        Constructor for Update: Instance of either UpdateNewMessage, UpdateMessageID, UpdateDeleteMessages, UpdateUserTyping, UpdateChatUserTyping, UpdateChatParticipants, UpdateUserStatus, UpdateUserName, UpdateUserPhoto, UpdateContactRegistered, UpdateContactLink, UpdateNewEncryptedMessage, UpdateEncryptedChatTyping, UpdateEncryption, UpdateEncryptedMessagesRead, UpdateChatParticipantAdd, UpdateChatParticipantDelete, UpdateDcOptions, UpdateUserBlocked, UpdateNotifySettings, UpdateServiceNotification, UpdatePrivacy, UpdateUserPhone, UpdateReadHistoryInbox, UpdateReadHistoryOutbox, UpdateWebPage, UpdateReadMessagesContents, UpdateChannelTooLong, UpdateChannel, UpdateNewChannelMessage, UpdateReadChannelInbox, UpdateDeleteChannelMessages, UpdateChannelMessageViews, UpdateChatAdmins, UpdateChatParticipantAdmin, UpdateNewStickerSet, UpdateStickerSetsOrder, UpdateStickerSets, UpdateSavedGifs, UpdateBotInlineQuery, UpdateBotInlineSend, UpdateEditChannelMessage, UpdateChannelPinnedMessage, UpdateBotCallbackQuery, UpdateEditMessage, UpdateInlineBotCallbackQuery, UpdateReadChannelOutbox, UpdateDraftMessage, UpdateReadFeaturedStickers, UpdateRecentStickers, UpdateConfig, UpdatePtsChanged, UpdateChannelWebPage, UpdateDialogPinned, UpdatePinnedDialogs, UpdateBotWebhookJSON, UpdateBotWebhookJSONQuery, UpdateBotShippingQuery, UpdateBotPrecheckoutQuery, UpdatePhoneCall.
        """
        super().__init__()

        self.dc_options = dc_options

    def on_send(self, writer):
        writer.write_int(UpdateDcOptions.constructor_id, signed=False)
        writer.write_int(0x1cb5c415, signed=False)  # Vector's constructor ID
        writer.write_int(len(self.dc_options))
        for dc_options_item in self.dc_options:
            dc_options_item.on_send(writer)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return UpdateDcOptions(None)

    def on_response(self, reader):
        reader.read_int()  # Vector's constructor ID
        self.dc_options = []  # Initialize an empty list
        dc_options_len = reader.read_int()
        for _ in range(dc_options_len):
            dc_options_item = reader.tgread_object()
            self.dc_options.append(dc_options_item)

    def __repr__(self):
        return 'updateDcOptions#8e5e9873 dc_options:Vector<DcOption> = Update'

    def __str__(self):
        return '(updateDcOptions (ID: 0x8e5e9873) = (dc_options={}))'.format(None if not self.dc_options else [str(_) for _ in self.dc_options])



from ...tl.mtproto_request import MTProtoRequest


class PageBlockChannel(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    pageBlockChannel#ef1751b5 channel:Chat = PageBlock"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0xef1751b5

    def __init__(self, channel):
        """
        :param channel: Telegram type: «Chat».

        Constructor for PageBlock: Instance of either PageBlockUnsupported, PageBlockTitle, PageBlockSubtitle, PageBlockAuthorDate, PageBlockHeader, PageBlockSubheader, PageBlockParagraph, PageBlockPreformatted, PageBlockFooter, PageBlockDivider, PageBlockAnchor, PageBlockList, PageBlockBlockquote, PageBlockPullquote, PageBlockPhoto, PageBlockVideo, PageBlockCover, PageBlockEmbed, PageBlockEmbedPost, PageBlockCollage, PageBlockSlideshow, PageBlockChannel.
        """
        super().__init__()

        self.channel = channel

    def on_send(self, writer):
        writer.write_int(PageBlockChannel.constructor_id, signed=False)
        self.channel.on_send(writer)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return PageBlockChannel(None)

    def on_response(self, reader):
        self.channel = reader.tgread_object()

    def __repr__(self):
        return 'pageBlockChannel#ef1751b5 channel:Chat = PageBlock'

    def __str__(self):
        return '(pageBlockChannel (ID: 0xef1751b5) = (channel={}))'.format(str(self.channel))



from ....tl.mtproto_request import MTProtoRequest


class GetWebPageRequest(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    messages.getWebPage#32ca8f91 url:string hash:int = WebPage"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0x32ca8f91

    def __init__(self, url, hash):
        """
        :param url: Telegram type: «string».
        :param hash: Telegram type: «int».

        :returns WebPage: Instance of either WebPageEmpty, WebPagePending, WebPage, WebPageNotModified.
        """
        super().__init__()
        self.result = None
        self.confirmed = True  # Confirmed by default

        self.url = url
        self.hash = hash

    def on_send(self, writer):
        writer.write_int(GetWebPageRequest.constructor_id, signed=False)
        writer.tgwrite_string(self.url)
        writer.write_int(self.hash)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return GetWebPageRequest(None, None)

    def on_response(self, reader):
        self.result = reader.tgread_object()

    def __repr__(self):
        return 'messages.getWebPage#32ca8f91 url:string hash:int = WebPage'

    def __str__(self):
        return '(messages.getWebPage (ID: 0x32ca8f91) = (url={}, hash={}))'.format(str(self.url), str(self.hash))



from ....tl.mtproto_request import MTProtoRequest


class RequestCallRequest(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    phone.requestCall#5b95b3d4 user_id:InputUser random_id:int g_a_hash:bytes protocol:PhoneCallProtocol = phone.PhoneCall"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0x5b95b3d4

    def __init__(self, user_id, random_id, g_a_hash, protocol):
        """
        :param user_id: Telegram type: «InputUser».
        :param random_id: Telegram type: «int».
        :param g_a_hash: Telegram type: «bytes».
        :param protocol: Telegram type: «PhoneCallProtocol».

        :returns phone.PhoneCall: Instance of PhoneCall.
        """
        super().__init__()
        self.result = None
        self.confirmed = True  # Confirmed by default

        self.user_id = user_id
        self.random_id = random_id
        self.g_a_hash = g_a_hash
        self.protocol = protocol

    def on_send(self, writer):
        writer.write_int(RequestCallRequest.constructor_id, signed=False)
        self.user_id.on_send(writer)
        writer.write_int(self.random_id)
        writer.tgwrite_bytes(self.g_a_hash)
        self.protocol.on_send(writer)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return RequestCallRequest(None, None, None, None)

    def on_response(self, reader):
        self.result = reader.tgread_object()

    def __repr__(self):
        return 'phone.requestCall#5b95b3d4 user_id:InputUser random_id:int g_a_hash:bytes protocol:PhoneCallProtocol = phone.PhoneCall'

    def __str__(self):
        return '(phone.requestCall (ID: 0x5b95b3d4) = (user_id={}, random_id={}, g_a_hash={}, protocol={}))'.format(str(self.user_id), str(self.random_id), str(self.g_a_hash), str(self.protocol))



from ....tl.mtproto_request import MTProtoRequest


class GetFileRequest(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    upload.getFile#e3a6cfb5 location:InputFileLocation offset:int limit:int = upload.File"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0xe3a6cfb5

    def __init__(self, location, offset, limit):
        """
        :param location: Telegram type: «InputFileLocation».
        :param offset: Telegram type: «int».
        :param limit: Telegram type: «int».

        :returns upload.File: Instance of either File, FileCdnRedirect.
        """
        super().__init__()
        self.result = None
        self.confirmed = True  # Confirmed by default

        self.location = location
        self.offset = offset
        self.limit = limit

    def on_send(self, writer):
        writer.write_int(GetFileRequest.constructor_id, signed=False)
        self.location.on_send(writer)
        writer.write_int(self.offset)
        writer.write_int(self.limit)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return GetFileRequest(None, None, None)

    def on_response(self, reader):
        self.result = reader.tgread_object()

    def __repr__(self):
        return 'upload.getFile#e3a6cfb5 location:InputFileLocation offset:int limit:int = upload.File'

    def __str__(self):
        return '(upload.getFile (ID: 0xe3a6cfb5) = (location={}, offset={}, limit={}))'.format(str(self.location), str(self.offset), str(self.limit))



from ...tl.mtproto_request import MTProtoRequest


class PeerSettings(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    peerSettings#818426cd flags:# report_spam:flags.0?true = PeerSettings"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0x818426cd

    def __init__(self, report_spam=None):
        """
        :param report_spam: Telegram type: «true».

        Constructor for PeerSettings: Instance of PeerSettings.
        """
        super().__init__()

        self.report_spam = report_spam

    def on_send(self, writer):
        writer.write_int(PeerSettings.constructor_id, signed=False)
        # Calculate the flags. This equals to those flag arguments which are NOT None
        flags = 0
        flags |= (1 << 0) if self.report_spam else 0
        writer.write_int(flags)


    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return PeerSettings(None)

    def on_response(self, reader):
        flags = reader.read_int()

        if (flags & (1 << 0)) != 0:
            self.report_spam = True  # Arbitrary not-None value, no need to read since it is a flag

    def __repr__(self):
        return 'peerSettings#818426cd flags:# report_spam:flags.0?true = PeerSettings'

    def __str__(self):
        return '(peerSettings (ID: 0x818426cd) = (report_spam={}))'.format(str(self.report_spam))



from ....tl.mtproto_request import MTProtoRequest


class ArchivedStickers(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    messages.archivedStickers#4fcba9c8 count:int sets:Vector<StickerSetCovered> = messages.ArchivedStickers"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0x4fcba9c8

    def __init__(self, count, sets):
        """
        :param count: Telegram type: «int».
        :param sets: Telegram type: «StickerSetCovered». Must be a list.

        Constructor for messages.ArchivedStickers: Instance of ArchivedStickers.
        """
        super().__init__()

        self.count = count
        self.sets = sets

    def on_send(self, writer):
        writer.write_int(ArchivedStickers.constructor_id, signed=False)
        writer.write_int(self.count)
        writer.write_int(0x1cb5c415, signed=False)  # Vector's constructor ID
        writer.write_int(len(self.sets))
        for sets_item in self.sets:
            sets_item.on_send(writer)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return ArchivedStickers(None, None)

    def on_response(self, reader):
        self.count = reader.read_int()
        reader.read_int()  # Vector's constructor ID
        self.sets = []  # Initialize an empty list
        sets_len = reader.read_int()
        for _ in range(sets_len):
            sets_item = reader.tgread_object()
            self.sets.append(sets_item)

    def __repr__(self):
        return 'messages.archivedStickers#4fcba9c8 count:int sets:Vector<StickerSetCovered> = messages.ArchivedStickers'

    def __str__(self):
        return '(messages.archivedStickers (ID: 0x4fcba9c8) = (count={}, sets={}))'.format(str(self.count), None if not self.sets else [str(_) for _ in self.sets])



from ....tl.mtproto_request import MTProtoRequest


class SendInlineBotResultRequest(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    messages.sendInlineBotResult#b16e06fe flags:# silent:flags.5?true background:flags.6?true clear_draft:flags.7?true peer:InputPeer reply_to_msg_id:flags.0?int random_id:long query_id:long id:string = Updates"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0xb16e06fe

    def __init__(self, peer, random_id, query_id, id, silent=None, background=None, clear_draft=None, reply_to_msg_id=None):
        """
        :param silent: Telegram type: «true».
        :param background: Telegram type: «true».
        :param clear_draft: Telegram type: «true».
        :param peer: Telegram type: «InputPeer».
        :param reply_to_msg_id: Telegram type: «int».
        :param random_id: Telegram type: «long».
        :param query_id: Telegram type: «long».
        :param id: Telegram type: «string».

        :returns Updates: Instance of either UpdatesTooLong, UpdateShortMessage, UpdateShortChatMessage, UpdateShort, UpdatesCombined, UpdatesTg, UpdateShortSentMessage.
        """
        super().__init__()
        self.result = None
        self.confirmed = True  # Confirmed by default

        self.silent = silent
        self.background = background
        self.clear_draft = clear_draft
        self.peer = peer
        self.reply_to_msg_id = reply_to_msg_id
        self.random_id = random_id
        self.query_id = query_id
        self.id = id

    def on_send(self, writer):
        writer.write_int(SendInlineBotResultRequest.constructor_id, signed=False)
        # Calculate the flags. This equals to those flag arguments which are NOT None
        flags = 0
        flags |= (1 << 5) if self.silent else 0
        flags |= (1 << 6) if self.background else 0
        flags |= (1 << 7) if self.clear_draft else 0
        flags |= (1 << 0) if self.reply_to_msg_id else 0
        writer.write_int(flags)

        self.peer.on_send(writer)
        if self.reply_to_msg_id:
            writer.write_int(self.reply_to_msg_id)

        writer.write_long(self.random_id)
        writer.write_long(self.query_id)
        writer.tgwrite_string(self.id)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return SendInlineBotResultRequest(None, None, None, None, None, None, None, None)

    def on_response(self, reader):
        self.result = reader.tgread_object()

    def __repr__(self):
        return 'messages.sendInlineBotResult#b16e06fe flags:# silent:flags.5?true background:flags.6?true clear_draft:flags.7?true peer:InputPeer reply_to_msg_id:flags.0?int random_id:long query_id:long id:string = Updates'

    def __str__(self):
        return '(messages.sendInlineBotResult (ID: 0xb16e06fe) = (silent={}, background={}, clear_draft={}, peer={}, reply_to_msg_id={}, random_id={}, query_id={}, id={}))'.format(str(self.silent), str(self.background), str(self.clear_draft), str(self.peer), str(self.reply_to_msg_id), str(self.random_id), str(self.query_id), str(self.id))



from ...tl.mtproto_request import MTProtoRequest


class DataJSON(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    dataJSON#7d748d04 data:string = DataJSON"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0x7d748d04

    def __init__(self, data):
        """
        :param data: Telegram type: «string».

        Constructor for DataJSON: Instance of DataJSON.
        """
        super().__init__()

        self.data = data

    def on_send(self, writer):
        writer.write_int(DataJSON.constructor_id, signed=False)
        writer.tgwrite_string(self.data)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return DataJSON(None)

    def on_response(self, reader):
        self.data = reader.tgread_string()

    def __repr__(self):
        return 'dataJSON#7d748d04 data:string = DataJSON'

    def __str__(self):
        return '(dataJSON (ID: 0x7d748d04) = (data={}))'.format(str(self.data))



from ...tl.mtproto_request import MTProtoRequest


class InputPaymentCredentials(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    inputPaymentCredentials#3417d728 flags:# save:flags.0?true data:DataJSON = InputPaymentCredentials"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0x3417d728

    def __init__(self, data, save=None):
        """
        :param save: Telegram type: «true».
        :param data: Telegram type: «DataJSON».

        Constructor for InputPaymentCredentials: Instance of either InputPaymentCredentialsSaved, InputPaymentCredentials.
        """
        super().__init__()

        self.save = save
        self.data = data

    def on_send(self, writer):
        writer.write_int(InputPaymentCredentials.constructor_id, signed=False)
        # Calculate the flags. This equals to those flag arguments which are NOT None
        flags = 0
        flags |= (1 << 0) if self.save else 0
        writer.write_int(flags)

        self.data.on_send(writer)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return InputPaymentCredentials(None, None)

    def on_response(self, reader):
        flags = reader.read_int()

        if (flags & (1 << 0)) != 0:
            self.save = True  # Arbitrary not-None value, no need to read since it is a flag

        self.data = reader.tgread_object()

    def __repr__(self):
        return 'inputPaymentCredentials#3417d728 flags:# save:flags.0?true data:DataJSON = InputPaymentCredentials'

    def __str__(self):
        return '(inputPaymentCredentials (ID: 0x3417d728) = (save={}, data={}))'.format(str(self.save), str(self.data))



from ....tl.mtproto_request import MTProtoRequest


class GetPeerDialogsRequest(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    messages.getPeerDialogs#2d9776b9 peers:Vector<InputPeer> = messages.PeerDialogs"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0x2d9776b9

    def __init__(self, peers):
        """
        :param peers: Telegram type: «InputPeer». Must be a list.

        :returns messages.PeerDialogs: Instance of PeerDialogs.
        """
        super().__init__()
        self.result = None
        self.confirmed = True  # Confirmed by default

        self.peers = peers

    def on_send(self, writer):
        writer.write_int(GetPeerDialogsRequest.constructor_id, signed=False)
        writer.write_int(0x1cb5c415, signed=False)  # Vector's constructor ID
        writer.write_int(len(self.peers))
        for peers_item in self.peers:
            peers_item.on_send(writer)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return GetPeerDialogsRequest(None)

    def on_response(self, reader):
        self.result = reader.tgread_object()

    def __repr__(self):
        return 'messages.getPeerDialogs#2d9776b9 peers:Vector<InputPeer> = messages.PeerDialogs'

    def __str__(self):
        return '(messages.getPeerDialogs (ID: 0x2d9776b9) = (peers={}))'.format(None if not self.peers else [str(_) for _ in self.peers])



from .get_call_config import GetCallConfigRequest
from .request_call import RequestCallRequest
from .accept_call import AcceptCallRequest
from .confirm_call import ConfirmCallRequest
from .received_call import ReceivedCallRequest
from .discard_call import DiscardCallRequest
from .set_call_rating import SetCallRatingRequest
from .save_call_debug import SaveCallDebugRequest



from ....tl.mtproto_request import MTProtoRequest


class GetUserPhotosRequest(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    photos.getUserPhotos#91cd32a8 user_id:InputUser offset:int max_id:long limit:int = photos.Photos"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0x91cd32a8

    def __init__(self, user_id, offset, max_id, limit):
        """
        :param user_id: Telegram type: «InputUser».
        :param offset: Telegram type: «int».
        :param max_id: Telegram type: «long».
        :param limit: Telegram type: «int».

        :returns photos.Photos: Instance of either Photos, PhotosSlice.
        """
        super().__init__()
        self.result = None
        self.confirmed = True  # Confirmed by default

        self.user_id = user_id
        self.offset = offset
        self.max_id = max_id
        self.limit = limit

    def on_send(self, writer):
        writer.write_int(GetUserPhotosRequest.constructor_id, signed=False)
        self.user_id.on_send(writer)
        writer.write_int(self.offset)
        writer.write_long(self.max_id)
        writer.write_int(self.limit)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return GetUserPhotosRequest(None, None, None, None)

    def on_response(self, reader):
        self.result = reader.tgread_object()

    def __repr__(self):
        return 'photos.getUserPhotos#91cd32a8 user_id:InputUser offset:int max_id:long limit:int = photos.Photos'

    def __str__(self):
        return '(photos.getUserPhotos (ID: 0x91cd32a8) = (user_id={}, offset={}, max_id={}, limit={}))'.format(str(self.user_id), str(self.offset), str(self.max_id), str(self.limit))



from ...tl.mtproto_request import MTProtoRequest


class PQInnerData(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    p_q_inner_data#83c95aec pq:string p:string q:string nonce:int128 server_nonce:int128 new_nonce:int256 = P_Q_inner_data"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0x83c95aec

    def __init__(self, pq, p, q, nonce, server_nonce, new_nonce):
        """
        :param pq: Telegram type: «string».
        :param p: Telegram type: «string».
        :param q: Telegram type: «string».
        :param nonce: Telegram type: «int128».
        :param server_nonce: Telegram type: «int128».
        :param new_nonce: Telegram type: «int256».

        Constructor for P_Q_inner_data: Instance of PQInnerData.
        """
        super().__init__()

        self.pq = pq
        self.p = p
        self.q = q
        self.nonce = nonce
        self.server_nonce = server_nonce
        self.new_nonce = new_nonce

    def on_send(self, writer):
        writer.write_int(PQInnerData.constructor_id, signed=False)
        writer.tgwrite_string(self.pq)
        writer.tgwrite_string(self.p)
        writer.tgwrite_string(self.q)
        writer.write_large_int(self.nonce, bits=128)
        writer.write_large_int(self.server_nonce, bits=128)
        writer.write_large_int(self.new_nonce, bits=256)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return PQInnerData(None, None, None, None, None, None)

    def on_response(self, reader):
        self.pq = reader.tgread_string()
        self.p = reader.tgread_string()
        self.q = reader.tgread_string()
        self.nonce = reader.read_large_int(bits=128)
        self.server_nonce = reader.read_large_int(bits=128)
        self.new_nonce = reader.read_large_int(bits=256)

    def __repr__(self):
        return 'p_q_inner_data#83c95aec pq:string p:string q:string nonce:int128 server_nonce:int128 new_nonce:int256 = P_Q_inner_data'

    def __str__(self):
        return '(p_q_inner_data (ID: 0x83c95aec) = (pq={}, p={}, q={}, nonce={}, server_nonce={}, new_nonce={}))'.format(str(self.pq), str(self.p), str(self.q), str(self.nonce), str(self.server_nonce), str(self.new_nonce))



from ....tl.mtproto_request import MTProtoRequest


class ReorderStickerSetsRequest(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    messages.reorderStickerSets#78337739 flags:# masks:flags.0?true order:Vector<long> = Bool"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0x78337739

    def __init__(self, order, masks=None):
        """
        :param masks: Telegram type: «true».
        :param order: Telegram type: «long». Must be a list.

        :returns Bool: This type has no constructors.
        """
        super().__init__()
        self.result = None
        self.confirmed = True  # Confirmed by default

        self.masks = masks
        self.order = order

    def on_send(self, writer):
        writer.write_int(ReorderStickerSetsRequest.constructor_id, signed=False)
        # Calculate the flags. This equals to those flag arguments which are NOT None
        flags = 0
        flags |= (1 << 0) if self.masks else 0
        writer.write_int(flags)

        writer.write_int(0x1cb5c415, signed=False)  # Vector's constructor ID
        writer.write_int(len(self.order))
        for order_item in self.order:
            writer.write_long(order_item)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return ReorderStickerSetsRequest(None, None)

    def on_response(self, reader):
        self.result = reader.tgread_object()

    def __repr__(self):
        return 'messages.reorderStickerSets#78337739 flags:# masks:flags.0?true order:Vector<long> = Bool'

    def __str__(self):
        return '(messages.reorderStickerSets (ID: 0x78337739) = (masks={}, order={}))'.format(str(self.masks), None if not self.order else [str(_) for _ in self.order])



from ....tl.mtproto_request import MTProtoRequest


class EditChatAdminRequest(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    messages.editChatAdmin#a9e69f2e chat_id:int user_id:InputUser is_admin:Bool = Bool"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0xa9e69f2e

    def __init__(self, chat_id, user_id, is_admin):
        """
        :param chat_id: Telegram type: «int».
        :param user_id: Telegram type: «InputUser».
        :param is_admin: Telegram type: «Bool».

        :returns Bool: This type has no constructors.
        """
        super().__init__()
        self.result = None
        self.confirmed = True  # Confirmed by default

        self.chat_id = chat_id
        self.user_id = user_id
        self.is_admin = is_admin

    def on_send(self, writer):
        writer.write_int(EditChatAdminRequest.constructor_id, signed=False)
        writer.write_int(self.chat_id)
        self.user_id.on_send(writer)
        writer.tgwrite_bool(self.is_admin)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return EditChatAdminRequest(None, None, None)

    def on_response(self, reader):
        self.result = reader.tgread_object()

    def __repr__(self):
        return 'messages.editChatAdmin#a9e69f2e chat_id:int user_id:InputUser is_admin:Bool = Bool'

    def __str__(self):
        return '(messages.editChatAdmin (ID: 0xa9e69f2e) = (chat_id={}, user_id={}, is_admin={}))'.format(str(self.chat_id), str(self.user_id), str(self.is_admin))



from ...tl.mtproto_request import MTProtoRequest


class UpdateEncryptedChatTyping(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    updateEncryptedChatTyping#1710f156 chat_id:int = Update"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0x1710f156

    def __init__(self, chat_id):
        """
        :param chat_id: Telegram type: «int».

        Constructor for Update: Instance of either UpdateNewMessage, UpdateMessageID, UpdateDeleteMessages, UpdateUserTyping, UpdateChatUserTyping, UpdateChatParticipants, UpdateUserStatus, UpdateUserName, UpdateUserPhoto, UpdateContactRegistered, UpdateContactLink, UpdateNewEncryptedMessage, UpdateEncryptedChatTyping, UpdateEncryption, UpdateEncryptedMessagesRead, UpdateChatParticipantAdd, UpdateChatParticipantDelete, UpdateDcOptions, UpdateUserBlocked, UpdateNotifySettings, UpdateServiceNotification, UpdatePrivacy, UpdateUserPhone, UpdateReadHistoryInbox, UpdateReadHistoryOutbox, UpdateWebPage, UpdateReadMessagesContents, UpdateChannelTooLong, UpdateChannel, UpdateNewChannelMessage, UpdateReadChannelInbox, UpdateDeleteChannelMessages, UpdateChannelMessageViews, UpdateChatAdmins, UpdateChatParticipantAdmin, UpdateNewStickerSet, UpdateStickerSetsOrder, UpdateStickerSets, UpdateSavedGifs, UpdateBotInlineQuery, UpdateBotInlineSend, UpdateEditChannelMessage, UpdateChannelPinnedMessage, UpdateBotCallbackQuery, UpdateEditMessage, UpdateInlineBotCallbackQuery, UpdateReadChannelOutbox, UpdateDraftMessage, UpdateReadFeaturedStickers, UpdateRecentStickers, UpdateConfig, UpdatePtsChanged, UpdateChannelWebPage, UpdateDialogPinned, UpdatePinnedDialogs, UpdateBotWebhookJSON, UpdateBotWebhookJSONQuery, UpdateBotShippingQuery, UpdateBotPrecheckoutQuery, UpdatePhoneCall.
        """
        super().__init__()

        self.chat_id = chat_id

    def on_send(self, writer):
        writer.write_int(UpdateEncryptedChatTyping.constructor_id, signed=False)
        writer.write_int(self.chat_id)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return UpdateEncryptedChatTyping(None)

    def on_response(self, reader):
        self.chat_id = reader.read_int()

    def __repr__(self):
        return 'updateEncryptedChatTyping#1710f156 chat_id:int = Update'

    def __str__(self):
        return '(updateEncryptedChatTyping (ID: 0x1710f156) = (chat_id={}))'.format(str(self.chat_id))



from ...tl.mtproto_request import MTProtoRequest


class InputMediaGeoPoint(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    inputMediaGeoPoint#f9c44144 geo_point:InputGeoPoint = InputMedia"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0xf9c44144

    def __init__(self, geo_point):
        """
        :param geo_point: Telegram type: «InputGeoPoint».

        Constructor for InputMedia: Instance of either InputMediaEmpty, InputMediaUploadedPhoto, InputMediaPhoto, InputMediaGeoPoint, InputMediaContact, InputMediaUploadedDocument, InputMediaUploadedThumbDocument, InputMediaDocument, InputMediaVenue, InputMediaGifExternal, InputMediaPhotoExternal, InputMediaDocumentExternal, InputMediaGame, InputMediaInvoice.
        """
        super().__init__()

        self.geo_point = geo_point

    def on_send(self, writer):
        writer.write_int(InputMediaGeoPoint.constructor_id, signed=False)
        self.geo_point.on_send(writer)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return InputMediaGeoPoint(None)

    def on_response(self, reader):
        self.geo_point = reader.tgread_object()

    def __repr__(self):
        return 'inputMediaGeoPoint#f9c44144 geo_point:InputGeoPoint = InputMedia'

    def __str__(self):
        return '(inputMediaGeoPoint (ID: 0xf9c44144) = (geo_point={}))'.format(str(self.geo_point))



from ...tl.mtproto_request import MTProtoRequest


class DestroySessionRequest(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    destroy_session#e7512126 session_id:long = DestroySessionRes"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0xe7512126

    def __init__(self, session_id):
        """
        :param session_id: Telegram type: «long».

        :returns DestroySessionRes: Instance of either DestroySessionOk, DestroySessionNone.
        """
        super().__init__()
        self.result = None
        self.confirmed = True  # Confirmed by default

        self.session_id = session_id

    def on_send(self, writer):
        writer.write_int(DestroySessionRequest.constructor_id, signed=False)
        writer.write_long(self.session_id)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return DestroySessionRequest(None)

    def on_response(self, reader):
        self.result = reader.tgread_object()

    def __repr__(self):
        return 'destroy_session#e7512126 session_id:long = DestroySessionRes'

    def __str__(self):
        return '(destroy_session (ID: 0xe7512126) = (session_id={}))'.format(str(self.session_id))



from ...tl.mtproto_request import MTProtoRequest


class PagePart(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    pagePart#8dee6c44 blocks:Vector<PageBlock> photos:Vector<Photo> videos:Vector<Document> = Page"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0x8dee6c44

    def __init__(self, blocks, photos, videos):
        """
        :param blocks: Telegram type: «PageBlock». Must be a list.
        :param photos: Telegram type: «Photo». Must be a list.
        :param videos: Telegram type: «Document». Must be a list.

        Constructor for Page: Instance of either PagePart, PageFull.
        """
        super().__init__()

        self.blocks = blocks
        self.photos = photos
        self.videos = videos

    def on_send(self, writer):
        writer.write_int(PagePart.constructor_id, signed=False)
        writer.write_int(0x1cb5c415, signed=False)  # Vector's constructor ID
        writer.write_int(len(self.blocks))
        for blocks_item in self.blocks:
            blocks_item.on_send(writer)

        writer.write_int(0x1cb5c415, signed=False)  # Vector's constructor ID
        writer.write_int(len(self.photos))
        for photos_item in self.photos:
            photos_item.on_send(writer)

        writer.write_int(0x1cb5c415, signed=False)  # Vector's constructor ID
        writer.write_int(len(self.videos))
        for videos_item in self.videos:
            videos_item.on_send(writer)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return PagePart(None, None, None)

    def on_response(self, reader):
        reader.read_int()  # Vector's constructor ID
        self.blocks = []  # Initialize an empty list
        blocks_len = reader.read_int()
        for _ in range(blocks_len):
            blocks_item = reader.tgread_object()
            self.blocks.append(blocks_item)

        reader.read_int()  # Vector's constructor ID
        self.photos = []  # Initialize an empty list
        photos_len = reader.read_int()
        for _ in range(photos_len):
            photos_item = reader.tgread_object()
            self.photos.append(photos_item)

        reader.read_int()  # Vector's constructor ID
        self.videos = []  # Initialize an empty list
        videos_len = reader.read_int()
        for _ in range(videos_len):
            videos_item = reader.tgread_object()
            self.videos.append(videos_item)

    def __repr__(self):
        return 'pagePart#8dee6c44 blocks:Vector<PageBlock> photos:Vector<Photo> videos:Vector<Document> = Page'

    def __str__(self):
        return '(pagePart (ID: 0x8dee6c44) = (blocks={}, photos={}, videos={}))'.format(None if not self.blocks else [str(_) for _ in self.blocks], None if not self.photos else [str(_) for _ in self.photos], None if not self.videos else [str(_) for _ in self.videos])



from .update_profile_photo import UpdateProfilePhotoRequest
from .upload_profile_photo import UploadProfilePhotoRequest
from .delete_photos import DeletePhotosRequest
from .get_user_photos import GetUserPhotosRequest



from ....tl.mtproto_request import MTProtoRequest


class ValidateRequestedInfoRequest(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    payments.validateRequestedInfo#770a8e74 flags:# save:flags.0?true msg_id:int info:PaymentRequestedInfo = payments.ValidatedRequestedInfo"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0x770a8e74

    def __init__(self, msg_id, info, save=None):
        """
        :param save: Telegram type: «true».
        :param msg_id: Telegram type: «int».
        :param info: Telegram type: «PaymentRequestedInfo».

        :returns payments.ValidatedRequestedInfo: Instance of ValidatedRequestedInfo.
        """
        super().__init__()
        self.result = None
        self.confirmed = True  # Confirmed by default

        self.save = save
        self.msg_id = msg_id
        self.info = info

    def on_send(self, writer):
        writer.write_int(ValidateRequestedInfoRequest.constructor_id, signed=False)
        # Calculate the flags. This equals to those flag arguments which are NOT None
        flags = 0
        flags |= (1 << 0) if self.save else 0
        writer.write_int(flags)

        writer.write_int(self.msg_id)
        self.info.on_send(writer)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return ValidateRequestedInfoRequest(None, None, None)

    def on_response(self, reader):
        self.result = reader.tgread_object()

    def __repr__(self):
        return 'payments.validateRequestedInfo#770a8e74 flags:# save:flags.0?true msg_id:int info:PaymentRequestedInfo = payments.ValidatedRequestedInfo'

    def __str__(self):
        return '(payments.validateRequestedInfo (ID: 0x770a8e74) = (save={}, msg_id={}, info={}))'.format(str(self.save), str(self.msg_id), str(self.info))



from ...tl.mtproto_request import MTProtoRequest


class InputWebFileLocation(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    inputWebFileLocation#c239d686 url:string access_hash:long = InputWebFileLocation"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0xc239d686

    def __init__(self, url, access_hash):
        """
        :param url: Telegram type: «string».
        :param access_hash: Telegram type: «long».

        Constructor for InputWebFileLocation: Instance of InputWebFileLocation.
        """
        super().__init__()

        self.url = url
        self.access_hash = access_hash

    def on_send(self, writer):
        writer.write_int(InputWebFileLocation.constructor_id, signed=False)
        writer.tgwrite_string(self.url)
        writer.write_long(self.access_hash)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return InputWebFileLocation(None, None)

    def on_response(self, reader):
        self.url = reader.tgread_string()
        self.access_hash = reader.read_long()

    def __repr__(self):
        return 'inputWebFileLocation#c239d686 url:string access_hash:long = InputWebFileLocation'

    def __str__(self):
        return '(inputWebFileLocation (ID: 0xc239d686) = (url={}, access_hash={}))'.format(str(self.url), str(self.access_hash))



from ...tl.mtproto_request import MTProtoRequest


class InputMessagesFilterPhoneCalls(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    inputMessagesFilterPhoneCalls#80c99768 flags:# missed:flags.0?true = MessagesFilter"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0x80c99768

    def __init__(self, missed=None):
        """
        :param missed: Telegram type: «true».

        Constructor for MessagesFilter: Instance of either InputMessagesFilterEmpty, InputMessagesFilterPhotos, InputMessagesFilterVideo, InputMessagesFilterPhotoVideo, InputMessagesFilterPhotoVideoDocuments, InputMessagesFilterDocument, InputMessagesFilterUrl, InputMessagesFilterGif, InputMessagesFilterVoice, InputMessagesFilterMusic, InputMessagesFilterChatPhotos, InputMessagesFilterPhoneCalls, InputMessagesFilterRoundVoice, InputMessagesFilterRoundVideo.
        """
        super().__init__()

        self.missed = missed

    def on_send(self, writer):
        writer.write_int(InputMessagesFilterPhoneCalls.constructor_id, signed=False)
        # Calculate the flags. This equals to those flag arguments which are NOT None
        flags = 0
        flags |= (1 << 0) if self.missed else 0
        writer.write_int(flags)


    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return InputMessagesFilterPhoneCalls(None)

    def on_response(self, reader):
        flags = reader.read_int()

        if (flags & (1 << 0)) != 0:
            self.missed = True  # Arbitrary not-None value, no need to read since it is a flag

    def __repr__(self):
        return 'inputMessagesFilterPhoneCalls#80c99768 flags:# missed:flags.0?true = MessagesFilter'

    def __str__(self):
        return '(inputMessagesFilterPhoneCalls (ID: 0x80c99768) = (missed={}))'.format(str(self.missed))



from ...tl.mtproto_request import MTProtoRequest


class Authorization(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    authorization#7bf2e6f6 hash:long flags:int device_model:string platform:string system_version:string api_id:int app_name:string app_version:string date_created:int date_active:int ip:string country:string region:string = Authorization"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0x7bf2e6f6

    def __init__(self, hash, flags, device_model, platform, system_version, api_id, app_name, app_version, date_created, date_active, ip, country, region):
        """
        :param hash: Telegram type: «long».
        :param flags: Telegram type: «int».
        :param device_model: Telegram type: «string».
        :param platform: Telegram type: «string».
        :param system_version: Telegram type: «string».
        :param api_id: Telegram type: «int».
        :param app_name: Telegram type: «string».
        :param app_version: Telegram type: «string».
        :param date_created: Telegram type: «int».
        :param date_active: Telegram type: «int».
        :param ip: Telegram type: «string».
        :param country: Telegram type: «string».
        :param region: Telegram type: «string».

        Constructor for Authorization: Instance of Authorization.
        """
        super().__init__()

        self.hash = hash
        self.flags = flags
        self.device_model = device_model
        self.platform = platform
        self.system_version = system_version
        self.api_id = api_id
        self.app_name = app_name
        self.app_version = app_version
        self.date_created = date_created
        self.date_active = date_active
        self.ip = ip
        self.country = country
        self.region = region

    def on_send(self, writer):
        writer.write_int(Authorization.constructor_id, signed=False)
        writer.write_long(self.hash)
        writer.write_int(self.flags)
        writer.tgwrite_string(self.device_model)
        writer.tgwrite_string(self.platform)
        writer.tgwrite_string(self.system_version)
        writer.write_int(self.api_id)
        writer.tgwrite_string(self.app_name)
        writer.tgwrite_string(self.app_version)
        writer.write_int(self.date_created)
        writer.write_int(self.date_active)
        writer.tgwrite_string(self.ip)
        writer.tgwrite_string(self.country)
        writer.tgwrite_string(self.region)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return Authorization(None, None, None, None, None, None, None, None, None, None, None, None, None)

    def on_response(self, reader):
        self.hash = reader.read_long()
        self.flags = reader.read_int()
        self.device_model = reader.tgread_string()
        self.platform = reader.tgread_string()
        self.system_version = reader.tgread_string()
        self.api_id = reader.read_int()
        self.app_name = reader.tgread_string()
        self.app_version = reader.tgread_string()
        self.date_created = reader.read_int()
        self.date_active = reader.read_int()
        self.ip = reader.tgread_string()
        self.country = reader.tgread_string()
        self.region = reader.tgread_string()

    def __repr__(self):
        return 'authorization#7bf2e6f6 hash:long flags:int device_model:string platform:string system_version:string api_id:int app_name:string app_version:string date_created:int date_active:int ip:string country:string region:string = Authorization'

    def __str__(self):
        return '(authorization (ID: 0x7bf2e6f6) = (hash={}, flags={}, device_model={}, platform={}, system_version={}, api_id={}, app_name={}, app_version={}, date_created={}, date_active={}, ip={}, country={}, region={}))'.format(str(self.hash), str(self.flags), str(self.device_model), str(self.platform), str(self.system_version), str(self.api_id), str(self.app_name), str(self.app_version), str(self.date_created), str(self.date_active), str(self.ip), str(self.country), str(self.region))



from ....tl.mtproto_request import MTProtoRequest


class SaveAppLogRequest(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    help.saveAppLog#6f02f748 events:Vector<InputAppEvent> = Bool"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0x6f02f748

    def __init__(self, events):
        """
        :param events: Telegram type: «InputAppEvent». Must be a list.

        :returns Bool: This type has no constructors.
        """
        super().__init__()
        self.result = None
        self.confirmed = True  # Confirmed by default

        self.events = events

    def on_send(self, writer):
        writer.write_int(SaveAppLogRequest.constructor_id, signed=False)
        writer.write_int(0x1cb5c415, signed=False)  # Vector's constructor ID
        writer.write_int(len(self.events))
        for events_item in self.events:
            events_item.on_send(writer)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return SaveAppLogRequest(None)

    def on_response(self, reader):
        self.result = reader.tgread_object()

    def __repr__(self):
        return 'help.saveAppLog#6f02f748 events:Vector<InputAppEvent> = Bool'

    def __str__(self):
        return '(help.saveAppLog (ID: 0x6f02f748) = (events={}))'.format(None if not self.events else [str(_) for _ in self.events])



from ...tl.mtproto_request import MTProtoRequest


class MessageMediaGeo(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    messageMediaGeo#56e0d474 geo:GeoPoint = MessageMedia"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0x56e0d474

    def __init__(self, geo):
        """
        :param geo: Telegram type: «GeoPoint».

        Constructor for MessageMedia: Instance of either MessageMediaEmpty, MessageMediaPhoto, MessageMediaGeo, MessageMediaContact, MessageMediaUnsupported, MessageMediaDocument, MessageMediaWebPage, MessageMediaVenue, MessageMediaGame, MessageMediaInvoice.
        """
        super().__init__()

        self.geo = geo

    def on_send(self, writer):
        writer.write_int(MessageMediaGeo.constructor_id, signed=False)
        self.geo.on_send(writer)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return MessageMediaGeo(None)

    def on_response(self, reader):
        self.geo = reader.tgread_object()

    def __repr__(self):
        return 'messageMediaGeo#56e0d474 geo:GeoPoint = MessageMedia'

    def __str__(self):
        return '(messageMediaGeo (ID: 0x56e0d474) = (geo={}))'.format(str(self.geo))



from ....tl.mtproto_request import MTProtoRequest


class CancelCodeRequest(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    auth.cancelCode#1f040578 phone_number:string phone_code_hash:string = Bool"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0x1f040578

    def __init__(self, phone_number, phone_code_hash):
        """
        :param phone_number: Telegram type: «string».
        :param phone_code_hash: Telegram type: «string».

        :returns Bool: This type has no constructors.
        """
        super().__init__()
        self.result = None
        self.confirmed = True  # Confirmed by default

        self.phone_number = phone_number
        self.phone_code_hash = phone_code_hash

    def on_send(self, writer):
        writer.write_int(CancelCodeRequest.constructor_id, signed=False)
        writer.tgwrite_string(self.phone_number)
        writer.tgwrite_string(self.phone_code_hash)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return CancelCodeRequest(None, None)

    def on_response(self, reader):
        self.result = reader.tgread_object()

    def __repr__(self):
        return 'auth.cancelCode#1f040578 phone_number:string phone_code_hash:string = Bool'

    def __str__(self):
        return '(auth.cancelCode (ID: 0x1f040578) = (phone_number={}, phone_code_hash={}))'.format(str(self.phone_number), str(self.phone_code_hash))



from ...tl.mtproto_request import MTProtoRequest


class MessageActionChatEditPhoto(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    messageActionChatEditPhoto#7fcb13a8 photo:Photo = MessageAction"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0x7fcb13a8

    def __init__(self, photo):
        """
        :param photo: Telegram type: «Photo».

        Constructor for MessageAction: Instance of either MessageActionEmpty, MessageActionChatCreate, MessageActionChatEditTitle, MessageActionChatEditPhoto, MessageActionChatDeletePhoto, MessageActionChatAddUser, MessageActionChatDeleteUser, MessageActionChatJoinedByLink, MessageActionChannelCreate, MessageActionChatMigrateTo, MessageActionChannelMigrateFrom, MessageActionPinMessage, MessageActionHistoryClear, MessageActionGameScore, MessageActionPaymentSentMe, MessageActionPaymentSent, MessageActionPhoneCall.
        """
        super().__init__()

        self.photo = photo

    def on_send(self, writer):
        writer.write_int(MessageActionChatEditPhoto.constructor_id, signed=False)
        self.photo.on_send(writer)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return MessageActionChatEditPhoto(None)

    def on_response(self, reader):
        self.photo = reader.tgread_object()

    def __repr__(self):
        return 'messageActionChatEditPhoto#7fcb13a8 photo:Photo = MessageAction'

    def __str__(self):
        return '(messageActionChatEditPhoto (ID: 0x7fcb13a8) = (photo={}))'.format(str(self.photo))



from ....tl.mtproto_request import MTProtoRequest


class CheckPhoneRequest(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    auth.checkPhone#6fe51dfb phone_number:string = auth.CheckedPhone"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0x6fe51dfb

    def __init__(self, phone_number):
        """
        :param phone_number: Telegram type: «string».

        :returns auth.CheckedPhone: Instance of CheckedPhone.
        """
        super().__init__()
        self.result = None
        self.confirmed = True  # Confirmed by default

        self.phone_number = phone_number

    def on_send(self, writer):
        writer.write_int(CheckPhoneRequest.constructor_id, signed=False)
        writer.tgwrite_string(self.phone_number)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return CheckPhoneRequest(None)

    def on_response(self, reader):
        self.result = reader.tgread_object()

    def __repr__(self):
        return 'auth.checkPhone#6fe51dfb phone_number:string = auth.CheckedPhone'

    def __str__(self):
        return '(auth.checkPhone (ID: 0x6fe51dfb) = (phone_number={}))'.format(str(self.phone_number))



from ...tl.mtproto_request import MTProtoRequest


class UpdateNewStickerSet(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    updateNewStickerSet#688a30aa stickerset:messages.StickerSet = Update"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0x688a30aa

    def __init__(self, stickerset):
        """
        :param stickerset: Telegram type: «messages.StickerSet».

        Constructor for Update: Instance of either UpdateNewMessage, UpdateMessageID, UpdateDeleteMessages, UpdateUserTyping, UpdateChatUserTyping, UpdateChatParticipants, UpdateUserStatus, UpdateUserName, UpdateUserPhoto, UpdateContactRegistered, UpdateContactLink, UpdateNewEncryptedMessage, UpdateEncryptedChatTyping, UpdateEncryption, UpdateEncryptedMessagesRead, UpdateChatParticipantAdd, UpdateChatParticipantDelete, UpdateDcOptions, UpdateUserBlocked, UpdateNotifySettings, UpdateServiceNotification, UpdatePrivacy, UpdateUserPhone, UpdateReadHistoryInbox, UpdateReadHistoryOutbox, UpdateWebPage, UpdateReadMessagesContents, UpdateChannelTooLong, UpdateChannel, UpdateNewChannelMessage, UpdateReadChannelInbox, UpdateDeleteChannelMessages, UpdateChannelMessageViews, UpdateChatAdmins, UpdateChatParticipantAdmin, UpdateNewStickerSet, UpdateStickerSetsOrder, UpdateStickerSets, UpdateSavedGifs, UpdateBotInlineQuery, UpdateBotInlineSend, UpdateEditChannelMessage, UpdateChannelPinnedMessage, UpdateBotCallbackQuery, UpdateEditMessage, UpdateInlineBotCallbackQuery, UpdateReadChannelOutbox, UpdateDraftMessage, UpdateReadFeaturedStickers, UpdateRecentStickers, UpdateConfig, UpdatePtsChanged, UpdateChannelWebPage, UpdateDialogPinned, UpdatePinnedDialogs, UpdateBotWebhookJSON, UpdateBotWebhookJSONQuery, UpdateBotShippingQuery, UpdateBotPrecheckoutQuery, UpdatePhoneCall.
        """
        super().__init__()

        self.stickerset = stickerset

    def on_send(self, writer):
        writer.write_int(UpdateNewStickerSet.constructor_id, signed=False)
        self.stickerset.on_send(writer)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return UpdateNewStickerSet(None)

    def on_response(self, reader):
        self.stickerset = reader.tgread_object()

    def __repr__(self):
        return 'updateNewStickerSet#688a30aa stickerset:messages.StickerSet = Update'

    def __str__(self):
        return '(updateNewStickerSet (ID: 0x688a30aa) = (stickerset={}))'.format(str(self.stickerset))



from ....tl.mtproto_request import MTProtoRequest


class GetAllChatsRequest(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    messages.getAllChats#eba80ff0 except_ids:Vector<int> = messages.Chats"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0xeba80ff0

    def __init__(self, except_ids):
        """
        :param except_ids: Telegram type: «int». Must be a list.

        :returns messages.Chats: Instance of either Chats, ChatsSlice.
        """
        super().__init__()
        self.result = None
        self.confirmed = True  # Confirmed by default

        self.except_ids = except_ids

    def on_send(self, writer):
        writer.write_int(GetAllChatsRequest.constructor_id, signed=False)
        writer.write_int(0x1cb5c415, signed=False)  # Vector's constructor ID
        writer.write_int(len(self.except_ids))
        for except_ids_item in self.except_ids:
            writer.write_int(except_ids_item)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return GetAllChatsRequest(None)

    def on_response(self, reader):
        self.result = reader.tgread_object()

    def __repr__(self):
        return 'messages.getAllChats#eba80ff0 except_ids:Vector<int> = messages.Chats'

    def __str__(self):
        return '(messages.getAllChats (ID: 0xeba80ff0) = (except_ids={}))'.format(None if not self.except_ids else [str(_) for _ in self.except_ids])



from ...tl.mtproto_request import MTProtoRequest


class ChannelFull(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    channelFull#c3d5512f flags:# can_view_participants:flags.3?true can_set_username:flags.6?true id:int about:string participants_count:flags.0?int admins_count:flags.1?int kicked_count:flags.2?int read_inbox_max_id:int read_outbox_max_id:int unread_count:int chat_photo:Photo notify_settings:PeerNotifySettings exported_invite:ExportedChatInvite bot_info:Vector<BotInfo> migrated_from_chat_id:flags.4?int migrated_from_max_id:flags.4?int pinned_msg_id:flags.5?int = ChatFull"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0xc3d5512f

    def __init__(self, id, about, read_inbox_max_id, read_outbox_max_id, unread_count, chat_photo, notify_settings, exported_invite, bot_info, can_view_participants=None, can_set_username=None, participants_count=None, admins_count=None, kicked_count=None, migrated_from_chat_id=None, migrated_from_max_id=None, pinned_msg_id=None):
        """
        :param can_view_participants: Telegram type: «true».
        :param can_set_username: Telegram type: «true».
        :param id: Telegram type: «int».
        :param about: Telegram type: «string».
        :param participants_count: Telegram type: «int».
        :param admins_count: Telegram type: «int».
        :param kicked_count: Telegram type: «int».
        :param read_inbox_max_id: Telegram type: «int».
        :param read_outbox_max_id: Telegram type: «int».
        :param unread_count: Telegram type: «int».
        :param chat_photo: Telegram type: «Photo».
        :param notify_settings: Telegram type: «PeerNotifySettings».
        :param exported_invite: Telegram type: «ExportedChatInvite».
        :param bot_info: Telegram type: «BotInfo». Must be a list.
        :param migrated_from_chat_id: Telegram type: «int».
        :param migrated_from_max_id: Telegram type: «int».
        :param pinned_msg_id: Telegram type: «int».

        Constructor for ChatFull: Instance of either ChatFull, ChannelFull.
        """
        super().__init__()

        self.can_view_participants = can_view_participants
        self.can_set_username = can_set_username
        self.id = id
        self.about = about
        self.participants_count = participants_count
        self.admins_count = admins_count
        self.kicked_count = kicked_count
        self.read_inbox_max_id = read_inbox_max_id
        self.read_outbox_max_id = read_outbox_max_id
        self.unread_count = unread_count
        self.chat_photo = chat_photo
        self.notify_settings = notify_settings
        self.exported_invite = exported_invite
        self.bot_info = bot_info
        self.migrated_from_chat_id = migrated_from_chat_id
        self.migrated_from_max_id = migrated_from_max_id
        self.pinned_msg_id = pinned_msg_id

    def on_send(self, writer):
        writer.write_int(ChannelFull.constructor_id, signed=False)
        # Calculate the flags. This equals to those flag arguments which are NOT None
        flags = 0
        flags |= (1 << 3) if self.can_view_participants else 0
        flags |= (1 << 6) if self.can_set_username else 0
        flags |= (1 << 0) if self.participants_count else 0
        flags |= (1 << 1) if self.admins_count else 0
        flags |= (1 << 2) if self.kicked_count else 0
        flags |= (1 << 4) if self.migrated_from_chat_id else 0
        flags |= (1 << 4) if self.migrated_from_max_id else 0
        flags |= (1 << 5) if self.pinned_msg_id else 0
        writer.write_int(flags)

        writer.write_int(self.id)
        writer.tgwrite_string(self.about)
        if self.participants_count:
            writer.write_int(self.participants_count)

        if self.admins_count:
            writer.write_int(self.admins_count)

        if self.kicked_count:
            writer.write_int(self.kicked_count)

        writer.write_int(self.read_inbox_max_id)
        writer.write_int(self.read_outbox_max_id)
        writer.write_int(self.unread_count)
        self.chat_photo.on_send(writer)
        self.notify_settings.on_send(writer)
        self.exported_invite.on_send(writer)
        writer.write_int(0x1cb5c415, signed=False)  # Vector's constructor ID
        writer.write_int(len(self.bot_info))
        for bot_info_item in self.bot_info:
            bot_info_item.on_send(writer)

        if self.migrated_from_chat_id:
            writer.write_int(self.migrated_from_chat_id)

        if self.migrated_from_max_id:
            writer.write_int(self.migrated_from_max_id)

        if self.pinned_msg_id:
            writer.write_int(self.pinned_msg_id)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return ChannelFull(None, None, None, None, None, None, None, None, None, None, None, None, None, None, None, None, None)

    def on_response(self, reader):
        flags = reader.read_int()

        if (flags & (1 << 3)) != 0:
            self.can_view_participants = True  # Arbitrary not-None value, no need to read since it is a flag

        if (flags & (1 << 6)) != 0:
            self.can_set_username = True  # Arbitrary not-None value, no need to read since it is a flag

        self.id = reader.read_int()
        self.about = reader.tgread_string()
        if (flags & (1 << 0)) != 0:
            self.participants_count = reader.read_int()

        if (flags & (1 << 1)) != 0:
            self.admins_count = reader.read_int()

        if (flags & (1 << 2)) != 0:
            self.kicked_count = reader.read_int()

        self.read_inbox_max_id = reader.read_int()
        self.read_outbox_max_id = reader.read_int()
        self.unread_count = reader.read_int()
        self.chat_photo = reader.tgread_object()
        self.notify_settings = reader.tgread_object()
        self.exported_invite = reader.tgread_object()
        reader.read_int()  # Vector's constructor ID
        self.bot_info = []  # Initialize an empty list
        bot_info_len = reader.read_int()
        for _ in range(bot_info_len):
            bot_info_item = reader.tgread_object()
            self.bot_info.append(bot_info_item)

        if (flags & (1 << 4)) != 0:
            self.migrated_from_chat_id = reader.read_int()

        if (flags & (1 << 4)) != 0:
            self.migrated_from_max_id = reader.read_int()

        if (flags & (1 << 5)) != 0:
            self.pinned_msg_id = reader.read_int()

    def __repr__(self):
        return 'channelFull#c3d5512f flags:# can_view_participants:flags.3?true can_set_username:flags.6?true id:int about:string participants_count:flags.0?int admins_count:flags.1?int kicked_count:flags.2?int read_inbox_max_id:int read_outbox_max_id:int unread_count:int chat_photo:Photo notify_settings:PeerNotifySettings exported_invite:ExportedChatInvite bot_info:Vector<BotInfo> migrated_from_chat_id:flags.4?int migrated_from_max_id:flags.4?int pinned_msg_id:flags.5?int = ChatFull'

    def __str__(self):
        return '(channelFull (ID: 0xc3d5512f) = (can_view_participants={}, can_set_username={}, id={}, about={}, participants_count={}, admins_count={}, kicked_count={}, read_inbox_max_id={}, read_outbox_max_id={}, unread_count={}, chat_photo={}, notify_settings={}, exported_invite={}, bot_info={}, migrated_from_chat_id={}, migrated_from_max_id={}, pinned_msg_id={}))'.format(str(self.can_view_participants), str(self.can_set_username), str(self.id), str(self.about), str(self.participants_count), str(self.admins_count), str(self.kicked_count), str(self.read_inbox_max_id), str(self.read_outbox_max_id), str(self.unread_count), str(self.chat_photo), str(self.notify_settings), str(self.exported_invite), None if not self.bot_info else [str(_) for _ in self.bot_info], str(self.migrated_from_chat_id), str(self.migrated_from_max_id), str(self.pinned_msg_id))



from ...tl.mtproto_request import MTProtoRequest


class TopPeerCategoryPeers(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    topPeerCategoryPeers#fb834291 category:TopPeerCategory count:int peers:Vector<TopPeer> = TopPeerCategoryPeers"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0xfb834291

    def __init__(self, category, count, peers):
        """
        :param category: Telegram type: «TopPeerCategory».
        :param count: Telegram type: «int».
        :param peers: Telegram type: «TopPeer». Must be a list.

        Constructor for TopPeerCategoryPeers: Instance of TopPeerCategoryPeers.
        """
        super().__init__()

        self.category = category
        self.count = count
        self.peers = peers

    def on_send(self, writer):
        writer.write_int(TopPeerCategoryPeers.constructor_id, signed=False)
        self.category.on_send(writer)
        writer.write_int(self.count)
        writer.write_int(0x1cb5c415, signed=False)  # Vector's constructor ID
        writer.write_int(len(self.peers))
        for peers_item in self.peers:
            peers_item.on_send(writer)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return TopPeerCategoryPeers(None, None, None)

    def on_response(self, reader):
        self.category = reader.tgread_object()
        self.count = reader.read_int()
        reader.read_int()  # Vector's constructor ID
        self.peers = []  # Initialize an empty list
        peers_len = reader.read_int()
        for _ in range(peers_len):
            peers_item = reader.tgread_object()
            self.peers.append(peers_item)

    def __repr__(self):
        return 'topPeerCategoryPeers#fb834291 category:TopPeerCategory count:int peers:Vector<TopPeer> = TopPeerCategoryPeers'

    def __str__(self):
        return '(topPeerCategoryPeers (ID: 0xfb834291) = (category={}, count={}, peers={}))'.format(str(self.category), str(self.count), None if not self.peers else [str(_) for _ in self.peers])



from ...tl.mtproto_request import MTProtoRequest


class UpdateUserBlocked(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    updateUserBlocked#80ece81a user_id:int blocked:Bool = Update"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0x80ece81a

    def __init__(self, user_id, blocked):
        """
        :param user_id: Telegram type: «int».
        :param blocked: Telegram type: «Bool».

        Constructor for Update: Instance of either UpdateNewMessage, UpdateMessageID, UpdateDeleteMessages, UpdateUserTyping, UpdateChatUserTyping, UpdateChatParticipants, UpdateUserStatus, UpdateUserName, UpdateUserPhoto, UpdateContactRegistered, UpdateContactLink, UpdateNewEncryptedMessage, UpdateEncryptedChatTyping, UpdateEncryption, UpdateEncryptedMessagesRead, UpdateChatParticipantAdd, UpdateChatParticipantDelete, UpdateDcOptions, UpdateUserBlocked, UpdateNotifySettings, UpdateServiceNotification, UpdatePrivacy, UpdateUserPhone, UpdateReadHistoryInbox, UpdateReadHistoryOutbox, UpdateWebPage, UpdateReadMessagesContents, UpdateChannelTooLong, UpdateChannel, UpdateNewChannelMessage, UpdateReadChannelInbox, UpdateDeleteChannelMessages, UpdateChannelMessageViews, UpdateChatAdmins, UpdateChatParticipantAdmin, UpdateNewStickerSet, UpdateStickerSetsOrder, UpdateStickerSets, UpdateSavedGifs, UpdateBotInlineQuery, UpdateBotInlineSend, UpdateEditChannelMessage, UpdateChannelPinnedMessage, UpdateBotCallbackQuery, UpdateEditMessage, UpdateInlineBotCallbackQuery, UpdateReadChannelOutbox, UpdateDraftMessage, UpdateReadFeaturedStickers, UpdateRecentStickers, UpdateConfig, UpdatePtsChanged, UpdateChannelWebPage, UpdateDialogPinned, UpdatePinnedDialogs, UpdateBotWebhookJSON, UpdateBotWebhookJSONQuery, UpdateBotShippingQuery, UpdateBotPrecheckoutQuery, UpdatePhoneCall.
        """
        super().__init__()

        self.user_id = user_id
        self.blocked = blocked

    def on_send(self, writer):
        writer.write_int(UpdateUserBlocked.constructor_id, signed=False)
        writer.write_int(self.user_id)
        writer.tgwrite_bool(self.blocked)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return UpdateUserBlocked(None, None)

    def on_response(self, reader):
        self.user_id = reader.read_int()
        self.blocked = reader.tgread_bool()

    def __repr__(self):
        return 'updateUserBlocked#80ece81a user_id:int blocked:Bool = Update'

    def __str__(self):
        return '(updateUserBlocked (ID: 0x80ece81a) = (user_id={}, blocked={}))'.format(str(self.user_id), str(self.blocked))



from ....tl.mtproto_request import MTProtoRequest


class DifferenceTooLong(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    updates.differenceTooLong#4afe8f6d pts:int = updates.Difference"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0x4afe8f6d

    def __init__(self, pts):
        """
        :param pts: Telegram type: «int».

        Constructor for updates.Difference: Instance of either DifferenceEmpty, Difference, DifferenceSlice, DifferenceTooLong.
        """
        super().__init__()

        self.pts = pts

    def on_send(self, writer):
        writer.write_int(DifferenceTooLong.constructor_id, signed=False)
        writer.write_int(self.pts)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return DifferenceTooLong(None)

    def on_response(self, reader):
        self.pts = reader.read_int()

    def __repr__(self):
        return 'updates.differenceTooLong#4afe8f6d pts:int = updates.Difference'

    def __str__(self):
        return '(updates.differenceTooLong (ID: 0x4afe8f6d) = (pts={}))'.format(str(self.pts))



from ....tl.mtproto_request import MTProtoRequest


class UpdateProfilePhotoRequest(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    photos.updateProfilePhoto#f0bb5152 id:InputPhoto = UserProfilePhoto"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0xf0bb5152

    def __init__(self, id):
        """
        :param id: Telegram type: «InputPhoto».

        :returns UserProfilePhoto: Instance of either UserProfilePhotoEmpty, UserProfilePhoto.
        """
        super().__init__()
        self.result = None
        self.confirmed = True  # Confirmed by default

        self.id = id

    def on_send(self, writer):
        writer.write_int(UpdateProfilePhotoRequest.constructor_id, signed=False)
        self.id.on_send(writer)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return UpdateProfilePhotoRequest(None)

    def on_response(self, reader):
        self.result = reader.tgread_object()

    def __repr__(self):
        return 'photos.updateProfilePhoto#f0bb5152 id:InputPhoto = UserProfilePhoto'

    def __str__(self):
        return '(photos.updateProfilePhoto (ID: 0xf0bb5152) = (id={}))'.format(str(self.id))



from ...tl.mtproto_request import MTProtoRequest


class PageBlockAnchor(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    pageBlockAnchor#ce0d37b0 name:string = PageBlock"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0xce0d37b0

    def __init__(self, name):
        """
        :param name: Telegram type: «string».

        Constructor for PageBlock: Instance of either PageBlockUnsupported, PageBlockTitle, PageBlockSubtitle, PageBlockAuthorDate, PageBlockHeader, PageBlockSubheader, PageBlockParagraph, PageBlockPreformatted, PageBlockFooter, PageBlockDivider, PageBlockAnchor, PageBlockList, PageBlockBlockquote, PageBlockPullquote, PageBlockPhoto, PageBlockVideo, PageBlockCover, PageBlockEmbed, PageBlockEmbedPost, PageBlockCollage, PageBlockSlideshow, PageBlockChannel.
        """
        super().__init__()

        self.name = name

    def on_send(self, writer):
        writer.write_int(PageBlockAnchor.constructor_id, signed=False)
        writer.tgwrite_string(self.name)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return PageBlockAnchor(None)

    def on_response(self, reader):
        self.name = reader.tgread_string()

    def __repr__(self):
        return 'pageBlockAnchor#ce0d37b0 name:string = PageBlock'

    def __str__(self):
        return '(pageBlockAnchor (ID: 0xce0d37b0) = (name={}))'.format(str(self.name))



from ....tl.mtproto_request import MTProtoRequest


class ConfirmCallRequest(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    phone.confirmCall#2efe1722 peer:InputPhoneCall g_a:bytes key_fingerprint:long protocol:PhoneCallProtocol = phone.PhoneCall"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0x2efe1722

    def __init__(self, peer, g_a, key_fingerprint, protocol):
        """
        :param peer: Telegram type: «InputPhoneCall».
        :param g_a: Telegram type: «bytes».
        :param key_fingerprint: Telegram type: «long».
        :param protocol: Telegram type: «PhoneCallProtocol».

        :returns phone.PhoneCall: Instance of PhoneCall.
        """
        super().__init__()
        self.result = None
        self.confirmed = True  # Confirmed by default

        self.peer = peer
        self.g_a = g_a
        self.key_fingerprint = key_fingerprint
        self.protocol = protocol

    def on_send(self, writer):
        writer.write_int(ConfirmCallRequest.constructor_id, signed=False)
        self.peer.on_send(writer)
        writer.tgwrite_bytes(self.g_a)
        writer.write_long(self.key_fingerprint)
        self.protocol.on_send(writer)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return ConfirmCallRequest(None, None, None, None)

    def on_response(self, reader):
        self.result = reader.tgread_object()

    def __repr__(self):
        return 'phone.confirmCall#2efe1722 peer:InputPhoneCall g_a:bytes key_fingerprint:long protocol:PhoneCallProtocol = phone.PhoneCall'

    def __str__(self):
        return '(phone.confirmCall (ID: 0x2efe1722) = (peer={}, g_a={}, key_fingerprint={}, protocol={}))'.format(str(self.peer), str(self.g_a), str(self.key_fingerprint), str(self.protocol))



from ...tl.mtproto_request import MTProtoRequest


class UpdateChatParticipantAdmin(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    updateChatParticipantAdmin#b6901959 chat_id:int user_id:int is_admin:Bool version:int = Update"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0xb6901959

    def __init__(self, chat_id, user_id, is_admin, version):
        """
        :param chat_id: Telegram type: «int».
        :param user_id: Telegram type: «int».
        :param is_admin: Telegram type: «Bool».
        :param version: Telegram type: «int».

        Constructor for Update: Instance of either UpdateNewMessage, UpdateMessageID, UpdateDeleteMessages, UpdateUserTyping, UpdateChatUserTyping, UpdateChatParticipants, UpdateUserStatus, UpdateUserName, UpdateUserPhoto, UpdateContactRegistered, UpdateContactLink, UpdateNewEncryptedMessage, UpdateEncryptedChatTyping, UpdateEncryption, UpdateEncryptedMessagesRead, UpdateChatParticipantAdd, UpdateChatParticipantDelete, UpdateDcOptions, UpdateUserBlocked, UpdateNotifySettings, UpdateServiceNotification, UpdatePrivacy, UpdateUserPhone, UpdateReadHistoryInbox, UpdateReadHistoryOutbox, UpdateWebPage, UpdateReadMessagesContents, UpdateChannelTooLong, UpdateChannel, UpdateNewChannelMessage, UpdateReadChannelInbox, UpdateDeleteChannelMessages, UpdateChannelMessageViews, UpdateChatAdmins, UpdateChatParticipantAdmin, UpdateNewStickerSet, UpdateStickerSetsOrder, UpdateStickerSets, UpdateSavedGifs, UpdateBotInlineQuery, UpdateBotInlineSend, UpdateEditChannelMessage, UpdateChannelPinnedMessage, UpdateBotCallbackQuery, UpdateEditMessage, UpdateInlineBotCallbackQuery, UpdateReadChannelOutbox, UpdateDraftMessage, UpdateReadFeaturedStickers, UpdateRecentStickers, UpdateConfig, UpdatePtsChanged, UpdateChannelWebPage, UpdateDialogPinned, UpdatePinnedDialogs, UpdateBotWebhookJSON, UpdateBotWebhookJSONQuery, UpdateBotShippingQuery, UpdateBotPrecheckoutQuery, UpdatePhoneCall.
        """
        super().__init__()

        self.chat_id = chat_id
        self.user_id = user_id
        self.is_admin = is_admin
        self.version = version

    def on_send(self, writer):
        writer.write_int(UpdateChatParticipantAdmin.constructor_id, signed=False)
        writer.write_int(self.chat_id)
        writer.write_int(self.user_id)
        writer.tgwrite_bool(self.is_admin)
        writer.write_int(self.version)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return UpdateChatParticipantAdmin(None, None, None, None)

    def on_response(self, reader):
        self.chat_id = reader.read_int()
        self.user_id = reader.read_int()
        self.is_admin = reader.tgread_bool()
        self.version = reader.read_int()

    def __repr__(self):
        return 'updateChatParticipantAdmin#b6901959 chat_id:int user_id:int is_admin:Bool version:int = Update'

    def __str__(self):
        return '(updateChatParticipantAdmin (ID: 0xb6901959) = (chat_id={}, user_id={}, is_admin={}, version={}))'.format(str(self.chat_id), str(self.user_id), str(self.is_admin), str(self.version))



from ...tl.mtproto_request import MTProtoRequest


class InputAppEvent(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    inputAppEvent#770656a8 time:double type:string peer:long data:string = InputAppEvent"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0x770656a8

    def __init__(self, time, type, peer, data):
        """
        :param time: Telegram type: «double».
        :param type: Telegram type: «string».
        :param peer: Telegram type: «long».
        :param data: Telegram type: «string».

        Constructor for InputAppEvent: Instance of InputAppEvent.
        """
        super().__init__()

        self.time = time
        self.type = type
        self.peer = peer
        self.data = data

    def on_send(self, writer):
        writer.write_int(InputAppEvent.constructor_id, signed=False)
        writer.write_double(self.time)
        writer.tgwrite_string(self.type)
        writer.write_long(self.peer)
        writer.tgwrite_string(self.data)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return InputAppEvent(None, None, None, None)

    def on_response(self, reader):
        self.time = reader.read_double()
        self.type = reader.tgread_string()
        self.peer = reader.read_long()
        self.data = reader.tgread_string()

    def __repr__(self):
        return 'inputAppEvent#770656a8 time:double type:string peer:long data:string = InputAppEvent'

    def __str__(self):
        return '(inputAppEvent (ID: 0x770656a8) = (time={}, type={}, peer={}, data={}))'.format(str(self.time), str(self.type), str(self.peer), str(self.data))



from ...tl.mtproto_request import MTProtoRequest


class InvokeWithoutUpdatesRequest(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    invokeWithoutUpdates#bf9459b7 {X:Type} query:!X = X"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0xbf9459b7

    def __init__(self, query):
        """
        :param query: Telegram type: «X». This should be another MTProtoRequest.

        :returns X: This type has no constructors.
        """
        super().__init__()
        self.result = None
        self.confirmed = True  # Confirmed by default

        self.query = query

    def on_send(self, writer):
        writer.write_int(InvokeWithoutUpdatesRequest.constructor_id, signed=False)
        self.query.on_send(writer)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return InvokeWithoutUpdatesRequest(None)

    def on_response(self, reader):
        self.result = reader.tgread_object()

    def __repr__(self):
        return 'invokeWithoutUpdates#bf9459b7 {X:Type} query:!X = X'

    def __str__(self):
        return '(invokeWithoutUpdates (ID: 0xbf9459b7) = (query={}))'.format(str(self.query))
